@@ -31,20 +31,19 @@
 
 #include "kpTransformResizeScaleDialog.h"
 
-#include <math.h>
 
-#include <qboxlayout.h>
-#include <qbuttongroup.h>
-#include <qcheckbox.h>
-#include <qcombobox.h>
-#include <qdialogbuttonbox.h>
-#include <qgridlayout.h>
-#include <qgroupbox.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpixmap.h>
-#include <qsize.h>
-#include <qtoolbutton.h>
+#include <QBoxLayout>
+#include <QButtonGroup>
+#include <QCheckBox>
+#include <QComboBox>
+#include <QDialogButtonBox>
+#include <QGridLayout>
+#include <QGroupBox>
+#include <QLabel>
+#include <QLayout>
+#include <QPixmap>
+#include <QSize>
+#include <QToolButton>
 #include <QSpinBox>
 #include <QDoubleSpinBox>
 
@@ -95,12 +94,12 @@ kpTransformResizeScaleDialog::kpTransformResizeScaleDialog (
     setWindowTitle (i18nc ("@title:window", "Resize / Scale"));
     QDialogButtonBox *buttons = new QDialogButtonBox (QDialogButtonBox::Ok |
                                                       QDialogButtonBox::Cancel, this);
-    connect (buttons, SIGNAL (accepted()), this, SLOT (accept()));
-    connect (buttons, SIGNAL (rejected()), this, SLOT (reject()));
+    connect (buttons, &QDialogButtonBox::accepted, this, &kpTransformResizeScaleDialog::accept);
+    connect (buttons, &QDialogButtonBox::rejected, this, &kpTransformResizeScaleDialog::reject);
 
     QWidget *baseWidget = new QWidget (this);
 
-    QVBoxLayout *dialogLayout = new QVBoxLayout (this);
+    auto *dialogLayout = new QVBoxLayout (this);
     dialogLayout->addWidget (baseWidget);
     dialogLayout->addWidget (buttons);
 
@@ -108,8 +107,8 @@ kpTransformResizeScaleDialog::kpTransformResizeScaleDialog (
     QGroupBox *operationGroupBox = createOperationGroupBox(baseWidget);
     QGroupBox *dimensionsGroupBox = createDimensionsGroupBox(baseWidget);
 
-    QVBoxLayout *baseLayout = new QVBoxLayout (baseWidget);
-    baseLayout->setMargin(0);
+    auto *baseLayout = new QVBoxLayout (baseWidget);
+    baseLayout->setContentsMargins(0, 0, 0, 0);
     baseLayout->addWidget(actOnBox);
     baseLayout->addWidget(operationGroupBox);
     baseLayout->addWidget(dimensionsGroupBox);
@@ -161,7 +160,7 @@ QWidget *kpTransformResizeScaleDialog::createActOnBox(QWidget *baseWidget)
     QWidget *actOnBox = new QWidget (baseWidget);
 
 
-    QLabel *actOnLabel = new QLabel (i18n ("Ac&t on:"), actOnBox);
+    auto *actOnLabel = new QLabel (i18n ("Ac&t on:"), actOnBox);
     m_actOnCombo = new QComboBox (actOnBox);
 
 
@@ -172,8 +171,9 @@ QWidget *kpTransformResizeScaleDialog::createActOnBox(QWidget *baseWidget)
     {
         QString selName = i18n ("Selection");
 
-        if (textSelection ())
+        if (textSelection ()) {
             selName = i18n ("Text Box");
+        }
 
         m_actOnCombo->insertItem (Selection, selName);
         m_actOnCombo->setCurrentIndex (Selection);
@@ -184,15 +184,13 @@ QWidget *kpTransformResizeScaleDialog::createActOnBox(QWidget *baseWidget)
         m_actOnCombo->setEnabled (false);
     }
 
-
-    QHBoxLayout *lay = new QHBoxLayout (actOnBox);
-    lay->setMargin (0);
+    auto *lay = new QHBoxLayout (actOnBox);
+    lay->setContentsMargins(0, 0, 0, 0);
     lay->addWidget (actOnLabel);
     lay->addWidget (m_actOnCombo, 1);
 
-
-    connect (m_actOnCombo, SIGNAL (activated(int)),
-             this, SLOT (slotActOnChanged()));
+    connect (m_actOnCombo, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated),
+             this, &kpTransformResizeScaleDialog::slotActOnChanged);
 
     return actOnBox;
 }
@@ -253,23 +251,23 @@ QGroupBox *kpTransformResizeScaleDialog::createOperationGroupBox (QWidget *baseW
                        QLatin1String ("smooth_scale"),
                        i18n ("S&mooth Scale"));
 
-    QButtonGroup *resizeScaleButtonGroup = new QButtonGroup (baseWidget);
+    auto *resizeScaleButtonGroup = new QButtonGroup (baseWidget);
     resizeScaleButtonGroup->addButton (m_resizeButton);
     resizeScaleButtonGroup->addButton (m_scaleButton);
     resizeScaleButtonGroup->addButton (m_smoothScaleButton);
 
 
-    QGridLayout *operationLayout = new QGridLayout (operationGroupBox );
+    auto *operationLayout = new QGridLayout (operationGroupBox );
     operationLayout->addWidget (m_resizeButton, 0, 0, Qt::AlignCenter);
     operationLayout->addWidget (m_scaleButton, 0, 1, Qt::AlignCenter);
     operationLayout->addWidget (m_smoothScaleButton, 0, 2, Qt::AlignCenter);
 
-    connect (m_resizeButton, SIGNAL (toggled(bool)),
-             this, SLOT (slotTypeChanged()));
-    connect (m_scaleButton, SIGNAL (toggled(bool)),
-             this, SLOT (slotTypeChanged()));
-    connect (m_smoothScaleButton, SIGNAL (toggled(bool)),
-             this, SLOT (slotTypeChanged()));
+    connect (m_resizeButton, &QToolButton::toggled,
+             this, &kpTransformResizeScaleDialog::slotTypeChanged);
+    connect (m_scaleButton, &QToolButton::toggled,
+             this, &kpTransformResizeScaleDialog::slotTypeChanged);
+    connect (m_smoothScaleButton, &QToolButton::toggled,
+             this, &kpTransformResizeScaleDialog::slotTypeChanged);
 
     return operationGroupBox;
 }
@@ -281,28 +279,28 @@ QGroupBox *kpTransformResizeScaleDialog::createDimensionsGroupBox(QWidget *baseW
 {
     QGroupBox *dimensionsGroupBox = new QGroupBox (i18n ("Dimensions"), baseWidget);
 
-    QLabel *widthLabel = new QLabel (i18n ("Width:"), dimensionsGroupBox);
+    auto *widthLabel = new QLabel (i18n ("Width:"), dimensionsGroupBox);
     widthLabel->setAlignment (widthLabel->alignment () | Qt::AlignHCenter);
-    QLabel *heightLabel = new QLabel (i18n ("Height:"), dimensionsGroupBox);
+    auto *heightLabel = new QLabel (i18n ("Height:"), dimensionsGroupBox);
     heightLabel->setAlignment (heightLabel->alignment () | Qt::AlignHCenter);
 
-    QLabel *originalLabel = new QLabel (i18n ("Original:"), dimensionsGroupBox);
+    auto *originalLabel = new QLabel (i18n ("Original:"), dimensionsGroupBox);
     m_originalWidthInput = new QSpinBox;
     m_originalWidthInput->setRange(1, INT_MAX);
-    m_originalWidthInput->setValue(document()->width((bool)selection()));
-    QLabel *xLabel0 = new QLabel (i18n ("x"), dimensionsGroupBox);
+    m_originalWidthInput->setValue(document()->width(static_cast<bool> (selection())));
+    auto *xLabel0 = new QLabel (i18n ("x"), dimensionsGroupBox);
     m_originalHeightInput = new QSpinBox;
     m_originalHeightInput->setRange(1, INT_MAX);
-    m_originalHeightInput->setValue(document()->height((bool)selection()));
+    m_originalHeightInput->setValue(document()->height(static_cast<bool> (selection())));
 
-    QLabel *newLabel = new QLabel (i18n ("&New:"), dimensionsGroupBox);
+    auto *newLabel = new QLabel (i18n ("&New:"), dimensionsGroupBox);
     m_newWidthInput = new QSpinBox;
     m_newWidthInput->setRange(1, INT_MAX);
-    QLabel *xLabel1 = new QLabel (i18n ("x"), dimensionsGroupBox);
+    auto *xLabel1 = new QLabel (i18n ("x"), dimensionsGroupBox);
     m_newHeightInput = new QSpinBox;
     m_newHeightInput->setRange(1, INT_MAX);
 
-    QLabel *percentLabel = new QLabel (i18n ("&Percent:"), dimensionsGroupBox);
+    auto *percentLabel = new QLabel (i18n ("&Percent:"), dimensionsGroupBox);
     m_percentWidthInput = new QDoubleSpinBox;
     m_percentWidthInput->setRange(0.01, 1000000);
     m_percentWidthInput->setValue(100);
@@ -310,7 +308,7 @@ QGroupBox *kpTransformResizeScaleDialog::createDimensionsGroupBox(QWidget *baseW
     m_percentWidthInput->setDecimals(2);
     m_percentWidthInput->setSuffix(i18n("%"));
 
-    QLabel *xLabel2 = new QLabel (i18n ("x"), dimensionsGroupBox);
+    auto *xLabel2 = new QLabel (i18n ("x"), dimensionsGroupBox);
 
     m_percentHeightInput = new QDoubleSpinBox;
     m_percentHeightInput->setRange(0.01, 1000000);
@@ -332,7 +330,7 @@ QGroupBox *kpTransformResizeScaleDialog::createDimensionsGroupBox(QWidget *baseW
     percentLabel->setBuddy (m_percentWidthInput);
 
 
-    QGridLayout *dimensionsLayout = new QGridLayout (dimensionsGroupBox);
+    auto *dimensionsLayout = new QGridLayout (dimensionsGroupBox);
     dimensionsLayout->setColumnStretch (1/*column*/, 1);
     dimensionsLayout->setColumnStretch (3/*column*/, 1);
 
@@ -360,10 +358,12 @@ QGroupBox *kpTransformResizeScaleDialog::createDimensionsGroupBox(QWidget *baseW
     dimensionsLayout->setRowMinimumHeight (4/*row*/, dimensionsLayout->rowMinimumHeight (4) * 2);
 
 
-    connect (m_newWidthInput, SIGNAL (valueChanged(int)),
-             this, SLOT (slotWidthChanged(int)));
-    connect (m_newHeightInput, SIGNAL (valueChanged(int)),
-             this, SLOT (slotHeightChanged(int)));
+
+    connect (m_newWidthInput, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
+             this, &kpTransformResizeScaleDialog::slotWidthChanged);
+
+    connect (m_newHeightInput, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
+             this, &kpTransformResizeScaleDialog::slotHeightChanged);
 
     // COMPAT: KDoubleNumInput only fires valueChanged(double) once per
     //         edit.  It should either fire:
@@ -376,13 +376,16 @@ QGroupBox *kpTransformResizeScaleDialog::createDimensionsGroupBox(QWidget *baseW
     //             2. Once per keystroke.
     //
     //         Bug in KDoubleNumInput.
-    connect (m_percentWidthInput, SIGNAL (valueChanged(double)),
-             this, SLOT (slotPercentWidthChanged(double)));
-    connect (m_percentHeightInput, SIGNAL (valueChanged(double)),
-             this, SLOT (slotPercentHeightChanged(double)));
+    connect (m_percentWidthInput,
+             static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+             this, &kpTransformResizeScaleDialog::slotPercentWidthChanged);
 
-    connect (m_keepAspectRatioCheckBox, SIGNAL (toggled(bool)),
-             this, SLOT (setKeepAspectRatio(bool)));
+    connect (m_percentHeightInput,
+             static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged),
+             this, &kpTransformResizeScaleDialog::slotPercentHeightChanged);
+
+    connect (m_keepAspectRatioCheckBox, &QCheckBox::toggled,
+             this, &kpTransformResizeScaleDialog::setKeepAspectRatio);
 
     return dimensionsGroupBox;
 }
@@ -464,20 +467,25 @@ void kpTransformResizeScaleDialog::slotActOnChanged ()
         }
         else
         {
-            if (m_lastType == kpTransformResizeScaleCommand::Scale)
+            if (m_lastType == kpTransformResizeScaleCommand::Scale) {
                 m_scaleButton->setChecked (true);
-            else
+            }
+            else {
                 m_smoothScaleButton->setChecked (true);
+            }
         }
     }
     else
     {
-        if (m_lastType == kpTransformResizeScaleCommand::Resize)
+        if (m_lastType == kpTransformResizeScaleCommand::Resize) {
             m_resizeButton->setChecked (true);
-        else if (m_lastType == kpTransformResizeScaleCommand::Scale)
+        }
+        else if (m_lastType == kpTransformResizeScaleCommand::Scale) {
             m_scaleButton->setChecked (true);
-        else
+        }
+        else {
             m_smoothScaleButton->setChecked (true);
+        }
     }
 
 
@@ -556,7 +564,7 @@ void kpTransformResizeScaleDialog::slotPercentWidthChanged (double percentWidth)
 {
 #if DEBUG_KP_TOOL_RESIZE_SCALE_DIALOG && 1
     qCDebug(kpLogDialogs) << "kpTransformResizeScaleDialog::slotPercentWidthChanged("
-               << percentWidth << ")" << endl;
+               << percentWidth << ")";
 #endif
 
     SET_VALUE_WITHOUT_SIGNAL_EMISSION (m_newWidthInput,
@@ -574,7 +582,7 @@ void kpTransformResizeScaleDialog::slotPercentHeightChanged (double percentHeigh
 {
 #if DEBUG_KP_TOOL_RESIZE_SCALE_DIALOG && 1
     qCDebug(kpLogDialogs) << "kpTransformResizeScaleDialog::slotPercentHeightChanged("
-               << percentHeight << ")" << endl;
+               << percentHeight << ")";
 #endif
 
     SET_VALUE_WITHOUT_SIGNAL_EMISSION (m_newHeightInput,
@@ -592,13 +600,16 @@ void kpTransformResizeScaleDialog::setKeepAspectRatio (bool on)
 {
 #if DEBUG_KP_TOOL_RESIZE_SCALE_DIALOG && 1
     qCDebug(kpLogDialogs) << "kpTransformResizeScaleDialog::setKeepAspectRatio("
-               << on << ")" << endl;
+               << on << ")";
 #endif
-    if (on != m_keepAspectRatioCheckBox->isChecked ())
-        m_keepAspectRatioCheckBox->setChecked (on);
 
-    if (on)
+    if (on != m_keepAspectRatioCheckBox->isChecked ()) {
+        m_keepAspectRatioCheckBox->setChecked (on);
+    }
+
+    if (on) {
         widthFitHeightToAspectRatio ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -652,12 +663,15 @@ bool kpTransformResizeScaleDialog::actOnSelection () const
 
 kpTransformResizeScaleCommand::Type kpTransformResizeScaleDialog::type () const
 {
-    if (m_resizeButton->isChecked ())
+    if (m_resizeButton->isChecked ()) {
         return kpTransformResizeScaleCommand::Resize;
-    else if (m_scaleButton->isChecked ())
+    }
+
+    if (m_scaleButton->isChecked ()) {
         return kpTransformResizeScaleCommand::Scale;
-    else
-        return kpTransformResizeScaleCommand::SmoothScale;
+    }
+
+    return kpTransformResizeScaleCommand::SmoothScale;
 }
 
 //---------------------------------------------------------------------
