@@ -31,21 +31,20 @@
 #include "kpDocument.h"
 #include "kpDocumentPrivate.h"
 
-#include <math.h>
 
-#include <qcolor.h>
-#include <qbitmap.h>
-#include <qbrush.h>
-#include <qfile.h>
-#include <qimage.h>
-#include <qlist.h>
+#include <QColor>
+#include <QBitmap>
+#include <QBrush>
+#include <QFile>
 #include <QImage>
-#include <qpainter.h>
-#include <qrect.h>
-#include <qsavefile.h>
-#include <qsize.h>
-#include <qtemporaryfile.h>
-#include <qmatrix.h>
+#include <QList>
+#include <QImage>
+#include <QPainter>
+#include <QRect>
+#include <QSaveFile>
+#include <QSize>
+#include <QTemporaryFile>
+#include <QTransform>
 #include <QMimeDatabase>
 
 #include "kpLogCategories.h"
@@ -75,8 +74,7 @@ bool kpDocument::save (bool overwritePrompt, bool lossyPrompt)
                << "overwritePrompt=" << overwritePrompt
                << ",lossyPrompt=" << lossyPrompt
                << ") url=" << m_url
-               << " savedAtLeastOnceBefore=" << savedAtLeastOnceBefore ()
-               << endl;
+               << " savedAtLeastOnceBefore=" << savedAtLeastOnceBefore ();
 #endif
 
     // TODO: check feels weak
@@ -173,29 +171,31 @@ bool kpDocument::savePixmapToDevice (const QImage &image,
                                      QWidget *parent,
                                      bool *userCancelled)
 {
-    if (userCancelled)
+    if (userCancelled) {
         *userCancelled = false;
+    }
 
     QStringList types = KImageIO::typeForMime (saveOptions.mimeType ());
 #if DEBUG_KP_DOCUMENT
     qCDebug(kpLogDocument) << "\ttypes=" << types;
 #endif
-    if (types.isEmpty ())
+    if (types.isEmpty ()) {
         return false;
-
+    }
     // It's safe to arbitrarily choose the 0th type as any type in the list
     // should invoke the same KImageIO image loader.
     const QString type = types [0];
 
 #if DEBUG_KP_DOCUMENT
     qCDebug(kpLogDocument) << "\tmimeType=" << saveOptions.mimeType ()
-               << " type=" << type << endl;
+               << " type=" << type;
 #endif
 
     if (lossyPrompt && !lossyPromptContinue (image, saveOptions, parent))
     {
-        if (userCancelled)
+        if (userCancelled) {
             *userCancelled = true;
+        }
 
     #if DEBUG_KP_DOCUMENT
         qCDebug(kpLogDocument) << "\treturning false because of lossyPrompt";
@@ -264,8 +264,9 @@ bool kpDocument::savePixmapToDevice (const QImage &image,
 
     int quality = -1;  // default
 
-    if (useSaveOptionsQuality)
+    if (useSaveOptionsQuality) {
         quality = saveOptions.quality ();
+    }
 
 #if DEBUG_KP_DOCUMENT
     qCDebug(kpLogDocument) << "\tsaving";
@@ -322,7 +323,7 @@ bool kpDocument::savePixmapToFile (const QImage &pixmap,
                << url
                << ",overwritePrompt=" << overwritePrompt
                << ",lossyPrompt=" << lossyPrompt
-               << ")" << endl;
+               << ")";
     saveOptions.printDebug (QLatin1String ("\tsaveOptions"));
     metaInfo.printDebug (QLatin1String ("\tmetaInfo"));
 #endif
@@ -505,10 +506,8 @@ bool kpDocument::saveAs (const QUrl &url,
         emit documentSaved ();
         return true;
     }
-    else
-    {
-        return false;
-    }
+
+    return false;
 }
 
 //---------------------------------------------------------------------
