@@ -31,7 +31,7 @@
 
 #include "kpEffectInvert.h"
 
-#include <qimage.h>
+#include <QImage>
 #include <QImage>
 
 #include "kpLogCategories.h"
@@ -48,16 +48,11 @@ void kpEffectInvert::applyEffect (QImage *destImagePtr, int channels)
                        0/*don't invert alpha*/);
 #if DEBUG_KP_EFFECT_INVERT
     qCDebug(kpLogImagelib) << "kpEffectInvert::applyEffect(channels=" << channels
-               << ") mask=" << (int *) mask
-               << endl;
+               << ") mask=" << (int *) mask;
 #endif
 
     if (destImagePtr->depth () > 8)
     {
-    #if 0
-        // SYNC: TODO: Qt BUG - invertAlpha argument is inverted!!!
-        destImagePtr->invertPixels (true/*no invert alpha (Qt 3.2)*/);
-    #else
         // Above version works for Qt 3.2 at least.
         // But this version will always work (slower, though) and supports
         // inverting particular channels.
@@ -68,7 +63,6 @@ void kpEffectInvert::applyEffect (QImage *destImagePtr, int channels)
                 destImagePtr->setPixel (x, y, destImagePtr->pixel (x, y) ^ mask);
             }
         }
-    #endif
     }
     else
     {
