@@ -29,13 +29,13 @@
 
 #include "kpViewScrollableContainer.h"
 
-#include <qbitmap.h>
-#include <qcursor.h>
-#include <qevent.h>
-#include <qpainter.h>
-#include <qpen.h>
-#include <qpixmap.h>
-#include <qtimer.h>
+#include <QBitmap>
+#include <QCursor>
+#include <QKeyEvent>
+#include <QPainter>
+#include <QPen>
+#include <QPixmap>
+#include <QTimer>
 #include <QScrollBar>
 
 #include "kpLogCategories.h"
@@ -120,15 +120,12 @@ QCursor kpGrip::cursorForType (GripType type)
     {
     case kpGrip::Bottom:
         return Qt::SizeVerCursor;
-        break;  // one day you'll forget
 
     case kpGrip::Right:
         return Qt::SizeHorCursor;
-        break;  // one day you'll forget
 
     case kpGrip::BottomRight:
         return Qt::SizeFDiagCursor;
-        break;  // one day you'll forget
     }
 
     return Qt::ArrowCursor;
@@ -189,8 +186,9 @@ void kpGrip::cancel ()
 #if DEBUG_KP_VIEW_SCROLLABLE_CONTAINER
     qCDebug(kpLogMisc) << "kpGrip::cancel()";
 #endif
-    if (m_currentPoint == KP_INVALID_POINT)
+    if (m_currentPoint == KP_INVALID_POINT) {
         return;
+    }
 
     m_startPoint = KP_INVALID_POINT;
     m_currentPoint = KP_INVALID_POINT;
@@ -233,8 +231,9 @@ void kpGrip::mousePressEvent (QMouseEvent *e)
     }
     else
     {
-        if (m_startPoint != KP_INVALID_POINT)
+        if (m_startPoint != KP_INVALID_POINT) {
             cancel ();
+        }
     }
 }
 
@@ -243,15 +242,16 @@ void kpGrip::mousePressEvent (QMouseEvent *e)
 // public
 QPoint kpGrip::viewDeltaPoint () const
 {
-    if (m_startPoint == KP_INVALID_POINT)
+    if (m_startPoint == KP_INVALID_POINT) {
         return KP_INVALID_POINT;
+    }
 
     const QPoint point = mapFromGlobal (QCursor::pos ());
 
     // TODO: this is getting out of sync with m_currentPoint
 
-    return QPoint (((m_type & kpGrip::Right) ? point.x () - m_startPoint.x () : 0),
-                   ((m_type & kpGrip::Bottom) ? point.y () - m_startPoint.y () : 0));
+    return  {(m_type & kpGrip::Right) ? point.x () - m_startPoint.x () : 0,
+                (m_type & kpGrip::Bottom) ? point.y () - m_startPoint.y () : 0};
 
 }
 
@@ -260,8 +260,9 @@ QPoint kpGrip::viewDeltaPoint () const
 // public
 void kpGrip::mouseMovedTo (const QPoint &point, bool dueToDragScroll)
 {
-    if (m_startPoint == KP_INVALID_POINT)
+    if (m_startPoint == KP_INVALID_POINT) {
         return;
+    }
 
     m_currentPoint = point;
 
@@ -277,14 +278,14 @@ void kpGrip::mouseMoveEvent (QMouseEvent *e)
 {
 #if DEBUG_KP_VIEW_SCROLLABLE_CONTAINER
     qCDebug(kpLogMisc) << "kpGrip::mouseMoveEvent() m_startPoint=" << m_startPoint
-               << " stateAfter: buttons=" << (int *) (int) e->buttons ()
-               << endl;
+               << " stateAfter: buttons=" << (int *) (int) e->buttons ();
 #endif
 
     if (m_startPoint == KP_INVALID_POINT)
     {
-        if ((e->buttons () & Qt::MouseButtonMask) == 0)
+        if ((e->buttons () & Qt::MouseButtonMask) == 0) {
             setUserMessage (haventBegunDrawUserMessage ());
+        }
         return;
     }
 
@@ -298,8 +299,7 @@ void kpGrip::mouseReleaseEvent (QMouseEvent *e)
 {
 #if DEBUG_KP_VIEW_SCROLLABLE_CONTAINER
     qCDebug(kpLogMisc) << "kpGrip::mouseReleaseEvent() m_startPoint=" << m_startPoint
-               << " stateAfter: buttons=" << (int *) (int) e->buttons ()
-               << endl;
+               << " stateAfter: buttons=" << (int *) (int) e->buttons ();
 #endif
 
     if (m_startPoint != KP_INVALID_POINT)
@@ -335,7 +335,7 @@ void kpGrip::enterEvent (QEvent * /*e*/)
     qCDebug(kpLogMisc) << "kpGrip::enterEvent()"
                << " m_startPoint=" << m_startPoint
                << " shouldReleaseMouseButtons="
-               << m_shouldReleaseMouseButtons << endl;
+               << m_shouldReleaseMouseButtons;
 #endif
 
     if (m_startPoint == KP_INVALID_POINT &&
@@ -357,7 +357,7 @@ void kpGrip::leaveEvent (QEvent * /*e*/)
     qCDebug(kpLogMisc) << "kpGrip::leaveEvent()"
                << " m_startPoint=" << m_startPoint
                << " shouldReleaseMouseButtons="
-               << m_shouldReleaseMouseButtons << endl;
+               << m_shouldReleaseMouseButtons;
 #endif
     if (m_startPoint == KP_INVALID_POINT &&
         !m_shouldReleaseMouseButtons)
@@ -404,14 +404,13 @@ kpViewScrollableContainer::kpViewScrollableContainer(QWidget *parent)
     connectGripSignals (m_bottomRightGrip);
 
 
-    connect (horizontalScrollBar(), SIGNAL(valueChanged(int)),
-             this, SLOT(slotContentsMoved()));
+    connect (horizontalScrollBar(), &QScrollBar::valueChanged,
+             this, &kpViewScrollableContainer::slotContentsMoved);
 
-    connect (verticalScrollBar(), SIGNAL(valueChanged(int)),
-             this, SLOT(slotContentsMoved()));
+    connect (verticalScrollBar(), &QScrollBar::valueChanged,
+             this, &kpViewScrollableContainer::slotContentsMoved);
 
-    connect (m_dragScrollTimer, SIGNAL (timeout()),
-             this, SLOT (slotDragScroll()));
+    connect (m_dragScrollTimer, &QTimer::timeout, this, [this]{slotDragScroll();});
 
     m_overlay->hide();
 }
@@ -421,20 +420,23 @@ kpViewScrollableContainer::kpViewScrollableContainer(QWidget *parent)
 // protected
 void kpViewScrollableContainer::connectGripSignals (kpGrip *grip)
 {
-    connect (grip, SIGNAL (beganDraw()),
-             this, SLOT (slotGripBeganDraw()));
-    connect (grip, SIGNAL (continuedDraw(int,int,bool)),
-             this, SLOT (slotGripContinuedDraw(int,int,bool)));
-    connect (grip, SIGNAL (cancelledDraw()),
-             this, SLOT (slotGripCancelledDraw()));
-    connect (grip, SIGNAL (endedDraw(int,int)),
-             this, SLOT (slotGripEndedDraw(int,int)));
+    connect (grip, &kpGrip::beganDraw,
+             this, &kpViewScrollableContainer::slotGripBeganDraw);
 
-    connect (grip, SIGNAL (statusMessageChanged(QString)),
-             this, SLOT (slotGripStatusMessageChanged(QString)));
+    connect (grip, &kpGrip::continuedDraw,
+             this, &kpViewScrollableContainer::slotGripContinuedDraw);
 
-    connect (grip, SIGNAL (releasedAllButtons()),
-             this, SLOT (recalculateStatusMessage()));
+    connect (grip, &kpGrip::cancelledDraw,
+             this, &kpViewScrollableContainer::slotGripCancelledDraw);
+
+    connect (grip, &kpGrip::endedDraw,
+             this, &kpViewScrollableContainer::slotGripEndedDraw);
+
+    connect (grip, &kpGrip::statusMessageChanged,
+             this, &kpViewScrollableContainer::slotGripStatusMessageChanged);
+
+    connect (grip, &kpGrip::releasedAllButtons,
+             this, &kpViewScrollableContainer::recalculateStatusMessage);
 }
 
 //---------------------------------------------------------------------
@@ -480,16 +482,18 @@ void kpViewScrollableContainer::clearStatusMessage ()
 // protected
 QSize kpViewScrollableContainer::newDocSize (int viewDX, int viewDY) const
 {
-    if (!m_view)
-        return QSize ();
+    if (!m_view) {
+        return {};
+    }
 
-    if (!docResizingGrip ())
-        return QSize ();
+    if (!docResizingGrip ()) {
+        return {};
+    }
 
-    const int docX = (int) m_view->transformViewToDocX (m_view->width () + viewDX);
-    const int docY = (int) m_view->transformViewToDocY (m_view->height () + viewDY);
+    const int docX = static_cast<int> (m_view->transformViewToDocX (m_view->width () + viewDX));
+    const int docY = static_cast<int> (m_view->transformViewToDocY (m_view->height () + viewDY));
 
-    return QSize (qMax (1, docX), qMax (1, docY));
+    return  {qMax (1, docX), qMax (1, docY)};
 }
 
 //---------------------------------------------------------------------
@@ -497,14 +501,18 @@ QSize kpViewScrollableContainer::newDocSize (int viewDX, int viewDY) const
 // protected
 void kpViewScrollableContainer::calculateDocResizingGrip ()
 {
-    if (m_bottomRightGrip->isDrawing ())
+    if (m_bottomRightGrip->isDrawing ()) {
         m_docResizingGrip = m_bottomRightGrip;
-    else if (m_bottomGrip->isDrawing ())
+    }
+    else if (m_bottomGrip->isDrawing ()) {
         m_docResizingGrip = m_bottomGrip;
-    else if (m_rightGrip->isDrawing ())
+    }
+    else if (m_rightGrip->isDrawing ()) {
         m_docResizingGrip = m_rightGrip;
-    else
+    }
+    else {
         m_docResizingGrip = nullptr;
+    }
 }
 
 //---------------------------------------------------------------------
@@ -520,16 +528,19 @@ kpGrip *kpViewScrollableContainer::docResizingGrip () const
 // protected
 int kpViewScrollableContainer::bottomResizeLineWidth () const
 {
-    if (!docResizingGrip ())
+    if (!docResizingGrip ()) {
         return -1;
+    }
 
-    if (!m_view)
+    if (!m_view) {
         return -1;
+    }
 
-    if (docResizingGrip ()->type () & kpGrip::Bottom)
+    if (docResizingGrip ()->type () & kpGrip::Bottom) {
         return qMax (m_view->zoomLevelY () / 100, 1);
-    else
-        return 1;
+    }
+
+    return 1;
 }
 
 //---------------------------------------------------------------------
@@ -537,16 +548,19 @@ int kpViewScrollableContainer::bottomResizeLineWidth () const
 // protected
 int kpViewScrollableContainer::rightResizeLineWidth () const
 {
-    if (!docResizingGrip ())
+    if (!docResizingGrip ()) {
         return -1;
+    }
 
-    if (!m_view)
+    if (!m_view) {
         return -1;
+    }
 
-    if (docResizingGrip ()->type () & kpGrip::Right)
+    if (docResizingGrip ()->type () & kpGrip::Right) {
         return qMax (m_view->zoomLevelX () / 100, 1);
-    else
-        return 1;
+    }
+
+    return 1;
 }
 
 //---------------------------------------------------------------------
@@ -554,8 +568,9 @@ int kpViewScrollableContainer::rightResizeLineWidth () const
 // protected
 QRect kpViewScrollableContainer::bottomResizeLineRect () const
 {
-    if (m_resizeRoundedLastViewX < 0 || m_resizeRoundedLastViewY < 0)
-        return QRect ();
+    if (m_resizeRoundedLastViewX < 0 || m_resizeRoundedLastViewY < 0) {
+        return  {};
+    }
 
     QRect visibleArea = QRect(QPoint(horizontalScrollBar()->value(),verticalScrollBar()->value()), viewport()->size());
 
@@ -570,8 +585,9 @@ QRect kpViewScrollableContainer::bottomResizeLineRect () const
 // protected
 QRect kpViewScrollableContainer::rightResizeLineRect () const
 {
-    if (m_resizeRoundedLastViewX < 0 || m_resizeRoundedLastViewY < 0)
-        return QRect ();
+    if (m_resizeRoundedLastViewX < 0 || m_resizeRoundedLastViewY < 0) {
+        return  {};
+    }
 
     QRect visibleArea = QRect(QPoint(horizontalScrollBar()->value(),verticalScrollBar()->value()), viewport()->size());
 
@@ -586,8 +602,9 @@ QRect kpViewScrollableContainer::rightResizeLineRect () const
 // protected
 QRect kpViewScrollableContainer::bottomRightResizeLineRect () const
 {
-    if (m_resizeRoundedLastViewX < 0 || m_resizeRoundedLastViewY < 0)
-        return QRect ();
+    if (m_resizeRoundedLastViewX < 0 || m_resizeRoundedLastViewY < 0) {
+        return  {};
+    }
 
     QRect visibleArea = QRect(QPoint(horizontalScrollBar()->value(),verticalScrollBar()->value()), viewport()->size());
 
@@ -602,8 +619,9 @@ QRect kpViewScrollableContainer::bottomRightResizeLineRect () const
 // private
 QRect kpViewScrollableContainer::mapViewToViewport (const QRect &viewRect)
 {
-    if (!viewRect.isValid ())
-        return QRect ();
+    if (!viewRect.isValid ()) {
+        return {};
+    }
 
     QRect ret = viewRect;
     ret.translate (-horizontalScrollBar()->value() - viewport()->x(), -verticalScrollBar()->value() - viewport()->y());
@@ -669,15 +687,17 @@ void kpViewScrollableContainer::updateResizeLines (int viewX, int viewY,
                << " oldViewX=" << m_resizeRoundedLastViewX
                << " oldViewY=" << m_resizeRoundedLastViewY
                << " viewDX=" << viewDX
-               << " viewDY=" << viewDY
-               << endl;
+               << " viewDY=" << viewDY;
 #endif
 
 
     if (viewX >= 0 && viewY >= 0)
     {
-        m_resizeRoundedLastViewX = (int) m_view->transformDocToViewX ((int) m_view->transformViewToDocX (viewX));
-        m_resizeRoundedLastViewY = (int) m_view->transformDocToViewY ((int) m_view->transformViewToDocY (viewY));
+        m_resizeRoundedLastViewX =
+                static_cast<int> (m_view->transformDocToViewX (m_view->transformViewToDocX (viewX)));
+
+        m_resizeRoundedLastViewY =
+                static_cast<int> (m_view->transformDocToViewY (m_view->transformViewToDocY (viewY)));
 
         m_resizeRoundedLastViewDX = viewDX;
         m_resizeRoundedLastViewDY = viewDY;
@@ -699,8 +719,9 @@ void kpViewScrollableContainer::updateResizeLines (int viewX, int viewY,
 // protected slot
 void kpViewScrollableContainer::slotGripBeganDraw ()
 {
-    if (!m_view)
+    if (!m_view) {
         return;
+    }
 
     m_overlay->resize(viewport()->size());  // make it cover whole viewport
     m_overlay->move(viewport()->pos());
@@ -730,12 +751,12 @@ void kpViewScrollableContainer::slotGripContinuedDraw (int inViewDX, int inViewD
     qCDebug(kpLogMisc) << "kpViewScrollableContainer::slotGripContinuedDraw("
                << viewDX << "," << viewDY << ") size="
                << newDocSize (viewDX, viewDY)
-               << " dueToDragScroll=" << dueToDragScroll
-               << endl;
+               << " dueToDragScroll=" << dueToDragScroll;
 #endif
 
-    if (!m_view)
+    if (!m_view) {
         return;
+    }
 
     if (!dueToDragScroll &&
         beginDragScroll(m_view->zoomLevelX ()))
@@ -745,15 +766,14 @@ void kpViewScrollableContainer::slotGripContinuedDraw (int inViewDX, int inViewD
         viewDY = newViewDeltaPoint.y ();
     #if DEBUG_KP_VIEW_SCROLLABLE_CONTAINER
         qCDebug(kpLogMisc) << "\tdrag scrolled - new view delta point="
-                   << newViewDeltaPoint
-                   << endl;
+                   << newViewDeltaPoint;
     #endif
     }
 
     m_haveMovedFromOriginalDocSize = true;
 
-    updateResizeLines (qMax (1, qMax (m_view->width () + viewDX, (int) m_view->transformDocToViewX (1))),
-                       qMax (1, qMax (m_view->height () + viewDY, (int) m_view->transformDocToViewY (1))),
+    updateResizeLines (qMax (1, qMax (m_view->width () + viewDX, static_cast<int> (m_view->transformDocToViewX (1)))),
+                       qMax (1, qMax (m_view->height () + viewDY, static_cast<int> (m_view->transformDocToViewY (1)))),
                        viewDX, viewDY);
 
     emit continuedDocResize (newDocSize ());
@@ -785,12 +805,12 @@ void kpViewScrollableContainer::slotGripEndedDraw (int viewDX, int viewDY)
 #if DEBUG_KP_VIEW_SCROLLABLE_CONTAINER
     qCDebug(kpLogMisc) << "kpViewScrollableContainer::slotGripEndedDraw("
                << viewDX << "," << viewDY << ") size="
-               << newDocSize (viewDX, viewDY)
-               << endl;
+               << newDocSize (viewDX, viewDY);
 #endif
 
-    if (!m_view)
+    if (!m_view) {
         return;
+    }
 
     const QSize newSize = newDocSize (viewDX, viewDY);
 
@@ -813,8 +833,9 @@ void kpViewScrollableContainer::slotGripEndedDraw (int viewDX, int viewDY)
 // protected slot
 void kpViewScrollableContainer::slotGripStatusMessageChanged (const QString &string)
 {
-    if (string == m_gripStatusMessage)
+    if (string == m_gripStatusMessage) {
         return;
+    }
 
     m_gripStatusMessage = string;
     emit statusMessageChanged (string);
@@ -830,8 +851,7 @@ void kpViewScrollableContainer::recalculateStatusMessage ()
     qCDebug(kpLogMisc) << "\tQCursor::pos=" << QCursor::pos ()
                << " global visibleRect="
                << kpWidgetMapper::toGlobal (this,
-                      QRect(0, 0, viewport->width(), viewport->height()))
-               << endl;
+                      QRect(0, 0, viewport->width(), viewport->height()));
 #endif
 
     // HACK: After dragging to a new size, handles move so that they are now
@@ -889,10 +909,12 @@ void kpViewScrollableContainer::slotContentsMoved ()
 // protected
 void kpViewScrollableContainer::disconnectViewSignals ()
 {
-    disconnect (m_view, SIGNAL (sizeChanged(QSize)),
-                this, SLOT (updateGrips()));
-    disconnect (m_view, SIGNAL (destroyed()),
-                this, SLOT (slotViewDestroyed()));
+    disconnect (m_view,
+                static_cast<void (kpView::*)(int, int)>(&kpView::sizeChanged),
+                this, &kpViewScrollableContainer::updateGrips);
+
+    disconnect (m_view, &kpView::destroyed,
+                this, &kpViewScrollableContainer::slotViewDestroyed);
 }
 
 //---------------------------------------------------------------------
@@ -900,10 +922,12 @@ void kpViewScrollableContainer::disconnectViewSignals ()
 // protected
 void kpViewScrollableContainer::connectViewSignals ()
 {
-    connect (m_view, SIGNAL (sizeChanged(QSize)),
-             this, SLOT (updateGrips()));
-    connect (m_view, SIGNAL (destroyed()),
-             this, SLOT (slotViewDestroyed()));
+    connect (m_view,
+             static_cast<void (kpView::*)(int, int)>(&kpView::sizeChanged),
+             this, &kpViewScrollableContainer::updateGrips);
+
+    connect (m_view, &kpView::destroyed,
+             this, &kpViewScrollableContainer::slotViewDestroyed);
 }
 
 //---------------------------------------------------------------------
@@ -919,8 +943,9 @@ kpView *kpViewScrollableContainer::view () const
 // public
 void kpViewScrollableContainer::setView (kpView *view)
 {
-    if (m_view == view)
+    if (m_view == view) {
         return;
+    }
 
     if (m_view)
     {
@@ -984,8 +1009,9 @@ void kpViewScrollableContainer::slotViewDestroyed ()
 // public slot
 bool kpViewScrollableContainer::beginDragScroll(int zoomLevel, bool *didSomething)
 {
-    if (didSomething)
+    if (didSomething) {
         *didSomething = false;
+    }
 
     m_zoomLevel = zoomLevel;
 
@@ -1012,11 +1038,13 @@ bool kpViewScrollableContainer::beginDragScroll(int zoomLevel, bool *didSomethin
         stopDragScroll = false;
     }
 
-    if (stopDragScroll)
+    if (stopDragScroll) {
         m_dragScrollTimer->stop ();
+    }
 
-    if (didSomething)
+    if (didSomething) {
         *didSomething = scrolled;
+    }
 
     return scrolled;
 }
@@ -1040,24 +1068,27 @@ bool kpViewScrollableContainer::endDragScroll ()
         m_dragScrollTimer->stop ();
         return true;
     }
-    else
-    {
-        return false;
-    }
+
+    return false;
 }
 
 //---------------------------------------------------------------------
 
 static int distanceFromRectToMultiplier (int dist)
 {
-    if (dist < 0)
+    if (dist < 0) {
         return 0;
-    else if (dist < DragDistanceFromRectMaxFor1stMultiplier)
+    }
+
+    if (dist < DragDistanceFromRectMaxFor1stMultiplier) {
         return 1;
-    else if (dist < DragDistanceFromRectMaxFor2ndMultiplier)
+    }
+
+    if (dist < DragDistanceFromRectMaxFor2ndMultiplier) {
         return 2;
-    else
-        return 4;
+    }
+
+    return 4;
 }
 
 //---------------------------------------------------------------------
@@ -1067,8 +1098,9 @@ bool kpViewScrollableContainer::slotDragScroll (bool *didSomething)
 {
     bool scrolled = false;
 
-    if (didSomething)
+    if (didSomething) {
         *didSomething = false;
+    }
 
 
     const QRect rect = noDragScrollRect ();
@@ -1129,19 +1161,13 @@ bool kpViewScrollableContainer::slotDragScroll (bool *didSomething)
     m_dragScrollTimer->start (DragScrollInterval);
     m_scrollTimerRunOnce = true;
 
-    if (didSomething)
+    if (didSomething) {
         *didSomething = scrolled;
+    }
 
     return scrolled;
 }
 
-//---------------------------------------------------------------------
-
-// protected slot
-bool kpViewScrollableContainer::slotDragScroll ()
-{
-    return slotDragScroll (nullptr/*don't want scrolled notification*/);
-}
 
 //---------------------------------------------------------------------
 
@@ -1150,20 +1176,22 @@ void kpViewScrollableContainer::wheelEvent (QWheelEvent *e)
 {
     e->ignore ();
 
-    if (m_view)
+    if (m_view) {
         m_view->wheelEvent (e);
+    }
 
-    if ( !e->isAccepted() )
+    if ( !e->isAccepted() ) {
         QScrollArea::wheelEvent(e);
+    }
 }
 
-//---------------------------------------------------------------------
+//---------------------------------------------------------------------------------
 
 QRect kpViewScrollableContainer::noDragScrollRect () const
 {
-    return QRect (DragScrollLeftTopMargin, DragScrollLeftTopMargin,
-                  width () - DragScrollLeftTopMargin - DragScrollRightBottomMargin,
-                  height () - DragScrollLeftTopMargin - DragScrollRightBottomMargin);
+    return  {DragScrollLeftTopMargin, DragScrollLeftTopMargin,
+                width () - DragScrollLeftTopMargin - DragScrollRightBottomMargin,
+                height () - DragScrollLeftTopMargin - DragScrollRightBottomMargin};
 }
 
 //---------------------------------------------------------------------
