@@ -52,9 +52,9 @@
 #include <kconfiggroup.h>
 #include <KLocalizedString>
 
-#include <qevent.h>
-#include <qmenu.h>
-#include <qtimer.h>
+#include <QEvent>
+#include <QMenu>
+#include <QTimer>
 
 #include "kpLogCategories.h"
 
@@ -121,8 +121,7 @@ void kpMainWindow::readGeneralSettings ()
         d->configOpenImagesInSameWindow = false;
 #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\tconfigOpenImagesInSameWindow: first time"
-                  << " - writing default: " << d->configOpenImagesInSameWindow
-                  << endl;
+                  << " - writing default: " << d->configOpenImagesInSameWindow;
 #endif
         // TODO: More hidden options have to write themselves out on startup,
         //       not on use, to be discoverable (e.g. printing centered on page).
@@ -164,8 +163,7 @@ void kpMainWindow::readThumbnailSettings ()
     qCDebug(kpLogMainWindow) << "\t\tThumbnail Settings: shown=" << d->configThumbnailShown
                << " geometry=" << d->configThumbnailGeometry
                << " zoomed=" << d->configZoomedThumbnail
-               << " showRectangle=" << d->configThumbnailShowRectangle
-               << endl;
+               << " showRectangle=" << d->configThumbnailShowRectangle;
 #endif
 }
 
@@ -177,7 +175,7 @@ void kpMainWindow::finalizeGUI(KXMLGUIClient *client)
   {
     const QList<QMenu *> menuToHide = findChildren<QMenu *>("toolToolBarHiddenMenu");
     // should only contain one but...
-    foreach (QMenu *menu, menuToHide)
+    for (auto *menu : menuToHide)
     {
         menu->menuAction()->setVisible(false);
     }
@@ -238,20 +236,24 @@ void kpMainWindow::init ()
 
     d->scrollView = new kpViewScrollableContainer (this);
     d->scrollView->setObjectName ( QLatin1String("scrollView" ));
-    connect (d->scrollView, SIGNAL (beganDocResize()),
-             this, SLOT (slotBeganDocResize()));
-    connect (d->scrollView, SIGNAL (continuedDocResize(QSize)),
-             this, SLOT (slotContinuedDocResize(QSize)));
-    connect (d->scrollView, SIGNAL (cancelledDocResize()),
-             this, SLOT (slotCancelledDocResize()));
-    connect (d->scrollView, SIGNAL (endedDocResize(QSize)),
-             this, SLOT (slotEndedDocResize(QSize)));
 
-    connect (d->scrollView, SIGNAL (statusMessageChanged(QString)),
-             this, SLOT (slotDocResizeMessageChanged(QString)));
+    connect (d->scrollView, &kpViewScrollableContainer::beganDocResize,
+             this, &kpMainWindow::slotBeganDocResize);
 
-    connect (d->scrollView, SIGNAL(contentsMoved()),
-             this, SLOT(slotScrollViewAfterScroll()));
+    connect (d->scrollView, &kpViewScrollableContainer::continuedDocResize,
+             this, &kpMainWindow::slotContinuedDocResize);
+
+    connect (d->scrollView, &kpViewScrollableContainer::cancelledDocResize,
+             this, &kpMainWindow::slotCancelledDocResize);
+
+    connect (d->scrollView, &kpViewScrollableContainer::endedDocResize,
+             this, &kpMainWindow::slotEndedDocResize);
+
+    connect (d->scrollView, &kpViewScrollableContainer::statusMessageChanged,
+             this, &kpMainWindow::slotDocResizeMessageChanged);
+
+    connect (d->scrollView, &kpViewScrollableContainer::contentsMoved,
+             this, &kpMainWindow::slotScrollViewAfterScroll);
 
     setCentralWidget (d->scrollView);
 
@@ -395,56 +397,6 @@ void kpMainWindow::saveProperties (KConfigGroup &configGroup)
         #endif
             configGroup.writeEntry (kpSessionSettingNotFromUrlDocumentSize, docSize);
         }
-
-
-        // Local session save i.e. queryClose() was not called beforehand
-        // (see QApplication::saveState())?
-    #if 0
-        if (d->document->isModified ())
-        {
-            // TODO: Implement by saving the current image to a persistent file.
-            //       We do this instead of saving/mutating the backing image file
-            //       as no one expects a file save on a session save without a
-            //       "do you want to save" dialog first.
-            //
-            //       I don't think any KDE application implements local session saving.
-            //
-            //       --- The below code does not compile but shows you want to do ---
-
-            // Create unique name for the document in this main window.
-            const QUrl tempURL = homeDir +
-                "kolourpaint session " + sessionID +
-                mainWindowPtrToString + ".png";
-            // TODO: Use lossless PNG saving options.
-            kpDocumentSaveOptions pngSaveOptions;
-
-            if (kpDocument::savePixmapToFile (d->document->pixmapWithSelection (),
-                    tempURL,
-                    pngSaveOptions, *d->document->metaInfo (),
-                    false/*no overwrite prompt*/,
-                    false/*no lossy prompt*/,
-                    this))
-            {
-                // readProperties() will still open kpSessionSettingDocumentUrl
-                // (as that's the expected URL) and will then add commands to:
-                //
-                // 1. Resize the document to the size of image at
-                //    kpSessionSettingDocumentUnsavedContentsUrl, if the sizes
-                //    differ.
-                // 2. Paste the kpSessionSettingDocumentUnsavedContentsUrl image
-                //    (setting the main window's selection mode to opaque beforehand).
-                //
-                // It will then delete the file at
-                // kpSessionSettingDocumentUnsavedContentsUrl.
-                configGroup.writeEntry (kpSessionSettingDocumentUnsavedContentsUrl,
-                    tempURL.url ());
-            }
-            else
-            {
-                // Not much we can do - we aren't allowed to throw up a dialog.
-            }
-        }
-    #endif
     }
 }
 
@@ -458,8 +410,9 @@ kpMainWindow::~kpMainWindow ()
     // Get the kpTool to finish up.  This makes sure that the kpTool destructor
     // will not need to access any other class (that might be deleted before
     // the destructor is called by the QObject child-deletion mechanism).
-    if (tool ())
+    if (tool ()) {
         tool ()->endInternal ();
+    }
 
     // Delete document & views.
     // Note: This will disconnects signals from the current kpTool, so kpTool
@@ -486,8 +439,9 @@ kpDocument *kpMainWindow::document () const
 // public
 kpDocumentEnvironment *kpMainWindow::documentEnvironment ()
 {
-    if (!d->documentEnvironment)
+    if (!d->documentEnvironment) {
         d->documentEnvironment = new kpDocumentEnvironment (this);
+    }
 
     return d->documentEnvironment;
 }
@@ -536,8 +490,9 @@ kpCommandHistory *kpMainWindow::commandHistory () const
 
 kpCommandEnvironment *kpMainWindow::commandEnvironment ()
 {
-    if (!d->commandEnvironment)
+    if (!d->commandEnvironment) {
         d->commandEnvironment = new kpCommandEnvironment (this);
+    }
 
     return d->commandEnvironment;
 }
@@ -655,7 +610,7 @@ void kpMainWindow::setDocument (kpDocument *newDoc)
     {
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\treparenting doc that may have been created into a"
-                  << " different mainWindiow" << endl;
+                  << " different mainWindiow";
     #endif
         d->document->setEnviron (documentEnvironment ());
 
@@ -676,16 +631,20 @@ void kpMainWindow::setDocument (kpDocument *newDoc)
     #endif
 
         // Copy/Cut/Deselect/Delete
-        connect (d->document, SIGNAL (selectionEnabled(bool)),
-                 d->actionCut, SLOT (setEnabled(bool)));
-        connect (d->document, SIGNAL (selectionEnabled(bool)),
-                 d->actionCopy, SLOT (setEnabled(bool)));
-        connect (d->document, SIGNAL (selectionEnabled(bool)),
-                 d->actionDelete, SLOT (setEnabled(bool)));
-        connect (d->document, SIGNAL (selectionEnabled(bool)),
-                 d->actionDeselect, SLOT (setEnabled(bool)));
-        connect (d->document, SIGNAL (selectionEnabled(bool)),
-                 d->actionCopyToFile, SLOT (setEnabled(bool)));
+        connect (d->document, &kpDocument::selectionEnabled,
+                 d->actionCut, &QAction::setEnabled);
+
+        connect (d->document, &kpDocument::selectionEnabled,
+                 d->actionCopy, &QAction::setEnabled);
+
+        connect (d->document, &kpDocument::selectionEnabled,
+                 d->actionDelete, &QAction::setEnabled);
+
+        connect (d->document, &kpDocument::selectionEnabled,
+                 d->actionDeselect, &QAction::setEnabled);
+
+        connect (d->document, &kpDocument::selectionEnabled,
+                 d->actionCopyToFile, &QAction::setEnabled);
 
         // this code won't actually enable any actions at this stage
         // (fresh document) but better safe than sorry
@@ -695,45 +654,54 @@ void kpMainWindow::setDocument (kpDocument *newDoc)
         d->actionDelete->setEnabled (d->document->selection ());
         d->actionCopyToFile->setEnabled (d->document->selection ());
 
-        connect (d->document, SIGNAL (selectionEnabled(bool)),
-                 this, SLOT (slotImageMenuUpdateDueToSelection()));
-        connect (d->document, SIGNAL (selectionIsTextChanged(bool)),
-                 this, SLOT (slotImageMenuUpdateDueToSelection()));
+        connect (d->document, &kpDocument::selectionEnabled,
+                 this, &kpMainWindow::slotImageMenuUpdateDueToSelection);
+
+        connect (d->document, &kpDocument::selectionIsTextChanged,
+                 this, &kpMainWindow::slotImageMenuUpdateDueToSelection);
 
         // Status bar
-        connect (d->document, SIGNAL (documentOpened()),
-                 this, SLOT (recalculateStatusBar()));
+        connect (d->document, &kpDocument::documentOpened,
+                 this, &kpMainWindow::recalculateStatusBar);
 
         connect (d->document, SIGNAL (sizeChanged(QSize)),
                  this, SLOT (setStatusBarDocSize(QSize)));
 
         // Caption (url, modified)
-        connect (d->document, SIGNAL (documentModified()),
-                 this, SLOT (slotUpdateCaption()));
-        connect (d->document, SIGNAL (documentOpened()),
-                 this, SLOT (slotUpdateCaption()));
-        connect (d->document, SIGNAL (documentSaved()),
-                 this, SLOT (slotUpdateCaption()));
+        connect (d->document, &kpDocument::documentModified,
+                 this, &kpMainWindow::slotUpdateCaption);
+
+        connect (d->document, &kpDocument::documentOpened,
+                 this, &kpMainWindow::slotUpdateCaption);
+
+        connect (d->document, &kpDocument::documentSaved,
+                 this, &kpMainWindow::slotUpdateCaption);
 
         // File/Reload action only available with non-empty URL
-        connect (d->document, SIGNAL (documentSaved()),
-                 this, SLOT (slotEnableReload()));
+        connect (d->document, &kpDocument::documentSaved,
+                 this, &kpMainWindow::slotEnableReload);
 
-        connect (d->document, SIGNAL (documentSaved()),
-                 this, SLOT (slotEnableSettingsShowPath()));
+        connect (d->document, &kpDocument::documentSaved,
+                 this, &kpMainWindow::slotEnableSettingsShowPath);
 
         // Command history
         Q_ASSERT (d->commandHistory);
-        connect (d->commandHistory, SIGNAL (documentRestored()),
-                 this, SLOT (slotDocumentRestored()));  // caption "!modified"
-        connect (d->document, SIGNAL (documentSaved()),
-                 d->commandHistory, SLOT (documentSaved()));
+        connect (d->commandHistory, &kpCommandHistory::documentRestored,
+                 this, &kpMainWindow::slotDocumentRestored); // caption "!modified"
+
+        connect (d->document, &kpDocument::documentSaved,
+                 d->commandHistory, &kpCommandHistory::documentSaved);
 
         // Sync document -> views
-        connect (d->document, SIGNAL (contentsChanged(QRect)),
-                 d->viewManager, SLOT (updateViews(QRect)));
-        connect (d->document, SIGNAL (sizeChanged(int,int)),
-                 d->viewManager, SLOT (adjustViewsToEnvironment()));
+        connect (d->document, &kpDocument::contentsChanged,
+                 d->viewManager, &kpViewManager::updateViews);
+
+        connect (d->document, static_cast<void (kpDocument::*)(int, int)>(&kpDocument::sizeChanged),
+                 d->viewManager, &kpViewManager::adjustViewsToEnvironment);
+
+        connect (d->document,
+                 static_cast<void (kpDocument::*)(int, int)>(&kpDocument::sizeChanged),
+                 d->viewManager, &kpViewManager::adjustViewsToEnvironment);
 
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\tenabling actions";
@@ -751,30 +719,6 @@ void kpMainWindow::setDocument (kpDocument *newDoc)
         enableToolsDocumentActions (true);
 
         enableDocumentActions (true);
-
-    // TODO: The thumbnail auto zoom doesn't work because it thinks its
-    //       width == 1 when !this->isShown().  So for consistency,
-    //       never create the thumbnail.
-    #if 0
-        if (d->configThumbnailShown)
-        {
-            if (isShown ())
-            {
-            #if DEBUG_KP_MAIN_WINDOW
-                qCDebug(kpLogMainWindow) << "\tcreating thumbnail immediately";
-            #endif
-                slotCreateThumbnail ();
-            }
-            // this' geometry is weird ATM
-            else
-            {
-            #if DEBUG_KP_MAIN_WINDOW
-                qCDebug(kpLogMainWindow) << "\tcreating thumbnail LATER";
-            #endif
-                QTimer::singleShot (0, this, SLOT (slotCreateThumbnail()));
-            }
-        }
-    #endif
     }
 
 #if DEBUG_KP_MAIN_WINDOW
@@ -787,8 +731,9 @@ void kpMainWindow::setDocument (kpDocument *newDoc)
     slotEnableReload ();
     slotEnableSettingsShowPath ();
 
-    if (d->commandHistory)
+    if (d->commandHistory) {
         d->commandHistory->clear ();
+    }
 
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\tdocument and views ready to go!";
@@ -835,7 +780,7 @@ void kpMainWindow::dropEvent (QDropEvent *e)
         //         However, you would need to prefix all possible error/warning
         //         dialogs that might be called, with Qt::arrowCursor e.g. in
         //         kpDocument  and probably a lot more places.
-        foreach (const QUrl &u, urls)
+        for (const auto &u : urls)
             open (u);
     }
     else if (e->mimeData ()->hasText ())
@@ -871,8 +816,7 @@ void kpMainWindow::dropEvent (QDropEvent *e)
                             << kpWidgetMapper::toGlobal (d->scrollView,
                                     QRect (0, 0,
                                             d->scrollView->viewport()->width (),
-                                            d->scrollView->viewport()->height ()))
-                            << endl;
+                                            d->scrollView->viewport()->height ()));
                 }
             #endif
                 if (d->thumbnailView &&
@@ -970,8 +914,9 @@ void kpMainWindow::slotUpdateCaption ()
 // private slot
 void kpMainWindow::slotDocumentRestored ()
 {
-    if (d->document)
+    if (d->document) {
         d->document->setModified (false);
+    }
     slotUpdateCaption ();
 }
 
