@@ -59,49 +59,49 @@ void kpMainWindow::setupColorsMenuActions ()
 
     d->actionColorsDefault = ac->addAction ("colors_default");
     d->actionColorsDefault->setText (i18n ("Use KolourPaint Defaults"));
-    connect (d->actionColorsDefault, SIGNAL (triggered(bool)),
-        SLOT (slotColorsDefault()));
+    connect (d->actionColorsDefault, &QAction::triggered,
+             this, &kpMainWindow::slotColorsDefault);
 
     d->actionColorsKDE = ac->add <KSelectAction> ("colors_kde");
     d->actionColorsKDE->setText (i18nc ("@item:inmenu colors", "Use KDE's"));
     // TODO: Will this slot be called spuriously if there are no colors
     //       installed?
-    connect (d->actionColorsKDE, SIGNAL (triggered(QAction*)),
-        SLOT (slotColorsKDE()));
-    foreach (const QString &colName, ::KDEColorCollectionNames ())
+    connect (d->actionColorsKDE,
+             static_cast<void (KSelectAction::*)(QAction*)>(&KSelectAction::triggered),
+             this, &kpMainWindow::slotColorsKDE);
+
+    for (const auto &colName : ::KDEColorCollectionNames ()) {
         d->actionColorsKDE->addAction (colName);
+    }
 
     d->actionColorsOpen = ac->addAction ("colors_open");
     d->actionColorsOpen->setText (i18nc ("@item:inmenu colors", "&Open..."));
-    connect (d->actionColorsOpen, SIGNAL (triggered(bool)),
-        SLOT (slotColorsOpen()));
+    connect (d->actionColorsOpen, &QAction::triggered, this, &kpMainWindow::slotColorsOpen);
 
     d->actionColorsReload = ac->addAction ("colors_reload");
     d->actionColorsReload->setText (i18nc ("@item:inmenu colors", "Reloa&d"));
-    connect (d->actionColorsReload, SIGNAL (triggered(bool)),
-        SLOT (slotColorsReload()));
-
+    connect (d->actionColorsReload, &QAction::triggered,
+             this, &kpMainWindow::slotColorsReload);
 
     d->actionColorsSave = ac->addAction ("colors_save");
     d->actionColorsSave->setText (i18nc ("@item:inmenu colors", "&Save"));
-    connect (d->actionColorsSave, SIGNAL (triggered(bool)),
-        SLOT (slotColorsSave()));
+    connect (d->actionColorsSave, &QAction::triggered,
+             this, &kpMainWindow::slotColorsSave);
 
     d->actionColorsSaveAs = ac->addAction ("colors_save_as");
     d->actionColorsSaveAs->setText (i18nc ("@item:inmenu colors", "Save &As..."));
-    connect (d->actionColorsSaveAs, SIGNAL (triggered(bool)),
-        SLOT (slotColorsSaveAs()));
-
+    connect (d->actionColorsSaveAs, &QAction::triggered,
+             this, &kpMainWindow::slotColorsSaveAs);
 
     d->actionColorsAppendRow = ac->addAction ("colors_append_row");
     d->actionColorsAppendRow->setText (i18nc ("@item:inmenu colors", "Add Row"));
-    connect (d->actionColorsAppendRow, SIGNAL (triggered(bool)),
-        SLOT (slotColorsAppendRow()));
+    connect (d->actionColorsAppendRow, &QAction::triggered,
+             this, &kpMainWindow::slotColorsAppendRow);
 
     d->actionColorsDeleteRow = ac->addAction ("colors_delete_row");
     d->actionColorsDeleteRow->setText (i18nc ("@item:inmenu colors", "Delete Last Row"));
-    connect (d->actionColorsDeleteRow, SIGNAL (triggered(bool)),
-        SLOT (slotColorsDeleteRow()));
+    connect (d->actionColorsDeleteRow, &QAction::triggered,
+             this, &kpMainWindow::slotColorsDeleteRow);
 
 
     enableColorsMenuDocumentActions (false);
@@ -117,8 +117,8 @@ void kpMainWindow::createColorBox ()
     // (needed for QMainWindow::saveState())
     d->colorToolBar->setObjectName ( QLatin1String("Color Box" ));
 
-    connect (colorCells (), SIGNAL (rowCountChanged(int)),
-        SLOT (slotUpdateColorsDeleteRowActionEnabled()));
+    connect (colorCells (), &kpColorCells::rowCountChanged,
+             this, &kpMainWindow::slotUpdateColorsDeleteRowActionEnabled);
 }
 
 //---------------------------------------------------------------------
@@ -187,8 +187,9 @@ bool kpMainWindow::queryCloseColors ()
 
     toolEndShape ();
 
-    if (!colorCells ()->isModified ())
+    if (!colorCells ()->isModified ()) {
         return true;  // ok to close
+    }
 
     int result = KMessageBox::Cancel;
 
@@ -253,8 +254,9 @@ void kpMainWindow::slotColorsDefault ()
     // Call just in case.
     toolEndShape ();
 
-    if (!queryCloseColors ())
+    if (!queryCloseColors ()) {
         return;
+    }
 
     openDefaultColors ();
 
@@ -303,19 +305,18 @@ void kpMainWindow::slotColorsKDE ()
         deselectActionColorsKDE ();
         return;
     }
-    else
-    {
-        // queryCloseColors() calls slotColorSave(), which can call
-        // slotColorSaveAs(), which can call deselectActionColorsKDE().
-        d->actionColorsKDE->setCurrentItem (curItem);
-    }
+
+    // queryCloseColors() calls slotColorSave(), which can call
+    // slotColorSaveAs(), which can call deselectActionColorsKDE().
+    d->actionColorsKDE->setCurrentItem (curItem);
 
     const QStringList colNames = ::KDEColorCollectionNames ();
     const int selected = d->actionColorsKDE->currentItem ();
     Q_ASSERT (selected >= 0 && selected < colNames.size ());
 
-    if (!openKDEColors (colNames [selected]))
+    if (!openKDEColors (colNames [selected])) {
         deselectActionColorsKDE ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -323,10 +324,7 @@ void kpMainWindow::slotColorsKDE ()
 // private
 bool kpMainWindow::openColors (const QUrl &url)
 {
-    if (!colorCells ()->openColorCollection (url))
-        return false;
-
-    return true;
+    return colorCells ()->openColorCollection (url);
 }
 
 //---------------------------------------------------------------------
@@ -343,12 +341,14 @@ void kpMainWindow::slotColorsOpen ()
 
     if (fd.exec ())
     {
-        if (!queryCloseColors ())
+        if (!queryCloseColors ()) {
             return;
+        }
 
         QList<QUrl> selected = fd.selectedUrls();
-        if ( selected.count() && openColors(selected[0]) )
+        if ( selected.count() && openColors(selected[0]) ) {
           deselectActionColorsKDE();
+        }
     }
 }
 
@@ -401,8 +401,9 @@ void kpMainWindow::slotColorsReload ()
         qCDebug(kpLogMainWindow) << "result=" << result
                   << "vs KMessageBox::Continue" << KMessageBox::Continue;
     #endif
-        if (result != KMessageBox::Continue)
+        if (result != KMessageBox::Continue) {
             return;
+        }
     }
 
 
@@ -413,10 +414,12 @@ void kpMainWindow::slotColorsReload ()
     else
     {
         const QString name = colorCells ()->colorCollection ()->name ();
-        if (!name.isEmpty ())
+        if (!name.isEmpty ()) {
             openKDEColors (name);
-        else
+        }
+        else {
             openDefaultColors ();
+        }
     }
 }
 
@@ -453,16 +456,17 @@ bool kpMainWindow::slotColorsSaveAs ()
     if (fd.exec ())
     {
         QList<QUrl> selected = fd.selectedUrls();
-        if ( !selected.count() || !colorCells ()->saveColorCollectionAs(selected[0]) )
+        if ( !selected.count() || !colorCells ()->saveColorCollectionAs(selected[0]) ) {
           return false;
+        }
 
         // We're definitely using our own color collection now.
         deselectActionColorsKDE ();
 
         return true;
     }
-    else
-        return false;
+
+    return false;
 }
 
 //---------------------------------------------------------------------
