@@ -66,9 +66,9 @@
 #include <KLocalizedString>
 #include <KIconLoader>
 
-#include <qaction.h>
-#include <qmenubar.h>
-#include <qsize.h>
+#include <QAction>
+#include <QMenuBar>
+#include <QSize>
 
 
 //---------------------------------------------------------------------
@@ -116,77 +116,79 @@ void kpMainWindow::setupImageMenuActions ()
 
     d->actionResizeScale = ac->addAction ("image_resize_scale");
     d->actionResizeScale->setText (i18n ("R&esize / Scale..."));
-    connect (d->actionResizeScale, SIGNAL (triggered(bool)), SLOT (slotResizeScale()));
+    connect (d->actionResizeScale, &QAction::triggered, this, &kpMainWindow::slotResizeScale);
+
     ac->setDefaultShortcut (d->actionResizeScale, Qt::CTRL + Qt::Key_E);
 
     d->actionCrop = ac->addAction ("image_crop");
     d->actionCrop->setText (i18n ("Se&t as Image (Crop)"));
-    connect (d->actionCrop, SIGNAL (triggered(bool)), SLOT (slotCrop()));
+    connect (d->actionCrop, &QAction::triggered, this, &kpMainWindow::slotCrop);
     ac->setDefaultShortcut (d->actionCrop, Qt::CTRL + Qt::Key_T);
 
     d->actionAutoCrop = ac->addAction ("image_auto_crop");
     d->actionAutoCrop->setText (autoCropText ());
-    connect (d->actionAutoCrop, SIGNAL (triggered(bool)), SLOT (slotAutoCrop()));
+    connect (d->actionAutoCrop, &QAction::triggered, this, &kpMainWindow::slotAutoCrop);
     ac->setDefaultShortcut (d->actionAutoCrop, Qt::CTRL + Qt::Key_U);
 
     d->actionFlip = ac->addAction ("image_flip");
     d->actionFlip->setText (i18n ("&Flip (upside down)"));
-    connect (d->actionFlip, SIGNAL (triggered(bool)), SLOT (slotFlip()));
+    connect (d->actionFlip, &QAction::triggered, this, &kpMainWindow::slotFlip);
     ac->setDefaultShortcut (d->actionFlip, Qt::CTRL + Qt::Key_F);
 
     d->actionMirror = ac->addAction ("image_mirror");
     d->actionMirror->setText (i18n ("Mirror (horizontally)"));
-    connect (d->actionMirror, SIGNAL (triggered(bool)), SLOT (slotMirror()));
+    connect (d->actionMirror, &QAction::triggered, this, &kpMainWindow::slotMirror);
     //ac->setDefaultShortcut (d->actionMirror, Qt::CTRL + Qt::Key_M);
 
     d->actionRotate = ac->addAction ("image_rotate");
     d->actionRotate->setText (i18n ("&Rotate..."));
     d->actionRotate->setIcon(KDE::icon("transform-rotate"));
-    connect (d->actionRotate, SIGNAL (triggered(bool)), SLOT (slotRotate()));
+    connect (d->actionRotate, &QAction::triggered, this, &kpMainWindow::slotRotate);
     ac->setDefaultShortcut (d->actionRotate, Qt::CTRL + Qt::Key_R);
 
     d->actionRotateLeft = ac->addAction ("image_rotate_270deg");
     d->actionRotateLeft->setText (i18n ("Rotate &Left"));
     d->actionRotateLeft->setIcon(KDE::icon("object-rotate-left"));
-    connect (d->actionRotateLeft, SIGNAL (triggered(bool)), SLOT (slotRotate270()));
+    connect (d->actionRotateLeft, &QAction::triggered, this, &kpMainWindow::slotRotate270);
     ac->setDefaultShortcut (d->actionRotateLeft, Qt::CTRL + Qt::SHIFT + Qt::Key_Left);
 
     d->actionRotateRight = ac->addAction ("image_rotate_90deg");
     d->actionRotateRight->setText (i18n ("Rotate Righ&t"));
     d->actionRotateRight->setIcon(KDE::icon("object-rotate-right"));
-    connect (d->actionRotateRight, SIGNAL (triggered(bool)), SLOT (slotRotate90()));
+    connect (d->actionRotateRight, &QAction::triggered, this, &kpMainWindow::slotRotate90);
     ac->setDefaultShortcut (d->actionRotateRight, Qt::CTRL + Qt::SHIFT + Qt::Key_Right);
 
     d->actionSkew = ac->addAction ("image_skew");
     d->actionSkew->setText (i18n ("S&kew..."));
-    connect (d->actionSkew, SIGNAL (triggered(bool)), SLOT (slotSkew()));
+    connect (d->actionSkew, &QAction::triggered, this, &kpMainWindow::slotSkew);
     ac->setDefaultShortcut (d->actionSkew, Qt::CTRL + Qt::Key_K);
 
     d->actionConvertToBlackAndWhite = ac->addAction ("image_convert_to_black_and_white");
     d->actionConvertToBlackAndWhite->setText (i18n ("Reduce to Mo&nochrome (Dithered)"));
-    connect (d->actionConvertToBlackAndWhite, SIGNAL (triggered(bool)), SLOT (slotConvertToBlackAndWhite()));
+    connect (d->actionConvertToBlackAndWhite, &QAction::triggered,
+             this, &kpMainWindow::slotConvertToBlackAndWhite);
 
     d->actionConvertToGrayscale = ac->addAction ("image_convert_to_grayscale");
     d->actionConvertToGrayscale->setText (i18n ("Reduce to &Grayscale"));
-    connect (d->actionConvertToGrayscale, SIGNAL (triggered(bool)), SLOT (slotConvertToGrayscale()));
+    connect (d->actionConvertToGrayscale, &QAction::triggered, this, &kpMainWindow::slotConvertToGrayscale);
 
     d->actionInvertColors = ac->addAction ("image_invert_colors");
     d->actionInvertColors->setText (i18n ("&Invert Colors"));
-    connect (d->actionInvertColors, SIGNAL (triggered(bool)), SLOT (slotInvertColors()));
+    connect (d->actionInvertColors, &QAction::triggered, this, &kpMainWindow::slotInvertColors);
     ac->setDefaultShortcut (d->actionInvertColors, Qt::CTRL + Qt::Key_I);
 
     d->actionClear = ac->addAction ("image_clear");
     d->actionClear->setText (i18n ("C&lear"));
-    connect (d->actionClear, SIGNAL (triggered(bool)), SLOT (slotClear()));
+    connect (d->actionClear, &QAction::triggered, this, &kpMainWindow::slotClear);
     ac->setDefaultShortcut (d->actionClear, Qt::CTRL + Qt::SHIFT + Qt::Key_N);
 
     d->actionBlur = ac->addAction("image_make_confidential");
     d->actionBlur->setText(i18n("Make Confidential"));
-    connect(d->actionBlur, SIGNAL(triggered(bool)), SLOT(slotMakeConfidential()));
+    connect(d->actionBlur, &QAction::triggered, this, &kpMainWindow::slotMakeConfidential);
 
     d->actionMoreEffects = ac->addAction ("image_more_effects");
     d->actionMoreEffects->setText (i18n ("&More Effects..."));
-    connect (d->actionMoreEffects, SIGNAL (triggered(bool)), SLOT (slotMoreEffects()));
+    connect (d->actionMoreEffects, &QAction::triggered, this, &kpMainWindow::slotMoreEffects);
     ac->setDefaultShortcut (d->actionMoreEffects, Qt::CTRL + Qt::Key_M);
 
 
@@ -233,15 +235,17 @@ void kpMainWindow::slotImageMenuUpdateDueToSelection ()
         "Select&ion");
 
     Q_ASSERT (menuBar ());
-    foreach (QAction *action, menuBar ()->actions ())
+    for (auto *action : menuBar ()->actions ())
     {
         if (action->text () == MenuBarItemTextImage ||
             action->text () == MenuBarItemTextSelection)
         {
-            if (isSelectionActive ())
+            if (isSelectionActive ()) {
                 action->setText (MenuBarItemTextSelection);
-            else
+            }
+            else {
                 action->setText (MenuBarItemTextImage);
+            }
 
             break;
         }
@@ -274,13 +278,12 @@ void kpMainWindow::slotImageMenuUpdateDueToSelection ()
 // public
 kpColor kpMainWindow::backgroundColor (bool ofSelection) const
 {
-    if (ofSelection)
+    if (ofSelection) {
         return kpColor::Transparent;
-    else
-    {
-        Q_ASSERT (d->colorToolBar);
-        return d->colorToolBar->backgroundColor ();
     }
+
+    Q_ASSERT (d->colorToolBar);
+    return d->colorToolBar->backgroundColor ();
 }
 
 //---------------------------------------------------------------------
@@ -294,33 +297,35 @@ void kpMainWindow::addImageOrSelectionCommand (kpCommand *cmd,
 #if DEBUG_KP_MAIN_WINDOW && 1
     qCDebug(kpLogMainWindow) << "kpMainWindow::addImageOrSelectionCommand()"
                << " addSelCreateCmdIfSelAvail=" << addSelCreateCmdIfSelAvail
-               << " addSelContentCmdIfSelAvail=" << addSelContentCmdIfSelAvail
-               << endl;
+               << " addSelContentCmdIfSelAvail=" << addSelContentCmdIfSelAvail;
 #endif
 
     Q_ASSERT (d->document);
 
 
-    if (d->viewManager)
+    if (d->viewManager) {
         d->viewManager->setQueueUpdates ();
+    }
 
 
     kpAbstractSelection *sel = d->document->selection ();
 #if DEBUG_KP_MAIN_WINDOW && 1
     qCDebug(kpLogMainWindow) << "\timage sel=" << sel
-               << " sel->hasContent=" << (sel ? sel->hasContent () : 0)
-               << endl;
+               << " sel->hasContent=" << (sel ? sel->hasContent () : 0);
 #endif
     if (addSelCreateCmdIfSelAvail && sel && !sel->hasContent ())
     {
         QString createCmdName;
 
-        if (dynamic_cast <kpAbstractImageSelection *> (sel))
+        if (dynamic_cast <kpAbstractImageSelection *> (sel)) {
             createCmdName = i18n ("Selection: Create");
-        else if (dynamic_cast <kpTextSelection *> (sel))
+        }
+        else if (dynamic_cast <kpTextSelection *> (sel)) {
             createCmdName = i18n ("Text: Create Box");
-        else
+        }
+        else {
             Q_ASSERT (!"Unknown selection type");
+        }
 
         // create selection region
         commandHistory ()->addCreateSelectionCommand (
@@ -334,13 +339,12 @@ void kpMainWindow::addImageOrSelectionCommand (kpCommand *cmd,
 
     if (addSelContentCmdIfSelAvail && sel && !sel->hasContent ())
     {
-        kpAbstractImageSelection *imageSel =
-            dynamic_cast <kpAbstractImageSelection *> (sel);
-        kpTextSelection *textSel =
-            dynamic_cast <kpTextSelection *> (sel);
+        auto *imageSel = dynamic_cast <kpAbstractImageSelection *> (sel);
+        auto *textSel = dynamic_cast <kpTextSelection *> (sel);
 
-        if (imageSel && imageSel->transparency ().isTransparent ())
+        if (imageSel && imageSel->transparency ().isTransparent ()) {
             d->colorToolBar->flashColorSimilarityToolBarItem ();
+        }
 
         kpMacroCommand *macroCmd = new kpMacroCommand (cmd->name (),
             commandEnvironment ());
@@ -362,8 +366,9 @@ void kpMainWindow::addImageOrSelectionCommand (kpCommand *cmd,
                     QString()/*uninteresting child of macro cmd*/,
                     commandEnvironment ()));
         }
-        else
+        else {
             Q_ASSERT (!"Unknown selection type");
+        }
 
         macroCmd->addCommand (cmd);
 
@@ -375,8 +380,9 @@ void kpMainWindow::addImageOrSelectionCommand (kpCommand *cmd,
     }
 
 
-    if (d->viewManager)
+    if (d->viewManager) {
         d->viewManager->restoreQueueUpdates ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -390,7 +396,7 @@ void kpMainWindow::slotResizeScale ()
 
     if (dialog.exec () && !dialog.isNoOp ())
     {
-        kpTransformResizeScaleCommand *cmd = new kpTransformResizeScaleCommand (
+        auto *cmd = new kpTransformResizeScaleCommand (
             dialog.actOnSelection (),
             dialog.imageWidth (), dialog.imageHeight (),
             dialog.type (),
@@ -469,7 +475,7 @@ void kpMainWindow::slotRotate ()
 {
     toolEndShape ();
 
-    kpTransformRotateDialog dialog ((bool) d->document->selection (),
+    kpTransformRotateDialog dialog (static_cast<bool> (d->document->selection ()),
         transformDialogEnvironment (), this);
 
     if (dialog.exec () && !dialog.isNoOp ())
@@ -513,7 +519,7 @@ void kpMainWindow::slotSkew ()
 {
     toolEndShape ();
 
-    kpTransformSkewDialog dialog ((bool) d->document->selection (),
+    kpTransformSkewDialog dialog (static_cast<bool> (d->document->selection ()),
         transformDialogEnvironment (), this);
 
     if (dialog.exec () && !dialog.isNoOp ())
@@ -594,7 +600,7 @@ void kpMainWindow::slotMoreEffects ()
 {
     toolEndShape ();
 
-    kpEffectsDialog dialog ((bool) d->document->selection (),
+    kpEffectsDialog dialog (static_cast<bool> (d->document->selection ()),
         transformDialogEnvironment (), this,
         d->moreEffectsDialogLastEffect);
 
