@@ -30,7 +30,7 @@
 #include "kpMainWindowPrivate.h"
 #include "kpLogCategories.h"
 
-#include <qtimer.h>
+#include <QTimer>
 
 #include <KSharedConfig>
 #include <kconfiggroup.h>
@@ -61,19 +61,19 @@ void kpMainWindow::setupViewMenuThumbnailActions ()
 
     d->actionShowThumbnail = ac->add <KToggleAction> ("view_show_thumbnail");
     d->actionShowThumbnail->setText (i18n ("Show T&humbnail"));
-    // TODO: This doesn't work when the thumbnail has focus. 
+    // TODO: This doesn't work when the thumbnail has focus.
     //       Testcase: Press CTRL+H twice on a fresh KolourPaint.
     //                 The second CTRL+H doesn't close the thumbnail.
     ac->setDefaultShortcut (d->actionShowThumbnail, Qt::CTRL + Qt::Key_H);
     //d->actionShowThumbnail->setCheckedState (KGuiItem(i18n ("Hide T&humbnail")));
-    connect (d->actionShowThumbnail, SIGNAL (triggered(bool)),
-        SLOT (slotShowThumbnailToggled()));
+    connect (d->actionShowThumbnail, &KToggleAction::triggered,
+             this, &kpMainWindow::slotShowThumbnailToggled);
 
     // Please do not use setCheckedState() here - it wouldn't make sense
     d->actionZoomedThumbnail = ac->add <KToggleAction> ("view_zoomed_thumbnail");
     d->actionZoomedThumbnail->setText (i18n ("Zoo&med Thumbnail Mode"));
-    connect (d->actionZoomedThumbnail, SIGNAL (triggered(bool)),
-        SLOT (slotZoomedThumbnailToggled()));
+    connect (d->actionZoomedThumbnail, &KToggleAction::triggered,
+             this, &kpMainWindow::slotZoomedThumbnailToggled);
 
     // For consistency with the above action, don't use setCheckedState()
     //
@@ -82,8 +82,8 @@ void kpMainWindow::setupViewMenuThumbnailActions ()
     // since rect _surrounds_ entire doc (hence, won't be rendered).
     d->actionShowThumbnailRectangle = ac->add <KToggleAction> ("view_show_thumbnail_rectangle");
     d->actionShowThumbnailRectangle->setText (i18n ("Enable Thumbnail &Rectangle"));
-    connect (d->actionShowThumbnailRectangle, SIGNAL (triggered(bool)),
-        SLOT (slotThumbnailShowRectangleToggled()));
+    connect (d->actionShowThumbnailRectangle, &KToggleAction::triggered,
+             this, &kpMainWindow::slotThumbnailShowRectangleToggled);
 }
 
 // private
@@ -139,8 +139,8 @@ void kpMainWindow::notifyThumbnailGeometryChanged ()
     {
         d->thumbnailSaveConfigTimer = new QTimer (this);
         d->thumbnailSaveConfigTimer->setSingleShot (true);
-        connect (d->thumbnailSaveConfigTimer, SIGNAL (timeout()),
-                 this, SLOT (slotSaveThumbnailGeometry()));
+        connect (d->thumbnailSaveConfigTimer, &QTimer::timeout,
+                 this, &kpMainWindow::slotSaveThumbnailGeometry);
     }
 
     // (single shot)
@@ -154,8 +154,9 @@ void kpMainWindow::slotSaveThumbnailGeometry ()
     qCDebug(kpLogMainWindow) << "kpMainWindow::saveThumbnailGeometry()";
 #endif
 
-    if (!d->thumbnail)
+    if (!d->thumbnail) {
         return;
+    }
 
     QRect rect (d->thumbnail->x (), d->thumbnail->y (),
                 d->thumbnail->width (), d->thumbnail->height ());
@@ -167,8 +168,7 @@ void kpMainWindow::slotSaveThumbnailGeometry ()
 
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\tCONFIG: saving thumbnail geometry "
-                << d->configThumbnailGeometry
-                << endl;
+                << d->configThumbnailGeometry;
 #endif
 
     KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupThumbnail);
@@ -201,11 +201,12 @@ void kpMainWindow::updateThumbnailZoomed ()
 {
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "kpMainWindow::updateThumbnailZoomed() zoomed="
-               << d->actionZoomedThumbnail->isChecked () << endl;
+               << d->actionZoomedThumbnail->isChecked ();
 #endif
 
-    if (!d->thumbnailView)
+    if (!d->thumbnailView) {
         return;
+    }
 
     destroyThumbnailView ();
     createThumbnailView ();
@@ -329,29 +330,36 @@ void kpMainWindow::createThumbnailView ()
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\t\tgive kpThumbnail the kpView:";
 #endif
-    if (d->thumbnail)
+
+    if (d->thumbnail) {
         d->thumbnail->setView (d->thumbnailView);
-    else
-        qCCritical(kpLogMainWindow) << "kpMainWindow::createThumbnailView() no thumbnail" << endl;
+    }
+    else {
+        qCCritical(kpLogMainWindow) << "kpMainWindow::createThumbnailView() no thumbnail";
+    }
 
 #if DEBUG_KP_MAIN_WINDOW
     qCDebug(kpLogMainWindow) << "\t\tregistering the kpView:";
 #endif
-    if (d->viewManager)
+    if (d->viewManager) {
         d->viewManager->registerView (d->thumbnailView);
+    }
 }
 
 // private
 void kpMainWindow::destroyThumbnailView ()
 {
-    if (!d->thumbnailView)
+    if (!d->thumbnailView) {
         return;
+    }
 
-    if (d->viewManager)
+    if (d->viewManager) {
         d->viewManager->unregisterView (d->thumbnailView);
+    }
 
-    if (d->thumbnail)
+    if (d->thumbnail) {
         d->thumbnail->setView (nullptr);
+    }
 
     d->thumbnailView->deleteLater (); d->thumbnailView = nullptr;
 }
@@ -369,12 +377,12 @@ void kpMainWindow::updateThumbnail ()
     qCDebug(kpLogMainWindow) << "\tthumbnail="
                << bool (d->thumbnail)
                << " action_isChecked="
-               << enable
-               << endl;
+               << enable;
 #endif
 
-    if (bool (d->thumbnail) == enable)
+    if (bool (d->thumbnail) == enable) {
         return;
+    }
 
     if (!d->thumbnail)
     {
@@ -436,8 +444,8 @@ void kpMainWindow::updateThumbnail ()
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\t\tconnecting signal thumbnail::windowClosed to destroy slot";
     #endif
-        connect (d->thumbnail, SIGNAL (windowClosed()),
-                 this, SLOT (slotDestroyThumbnailInitatedByUser()));
+        connect (d->thumbnail, &kpThumbnail::windowClosed,
+                 this, &kpMainWindow::slotDestroyThumbnailInitatedByUser);
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\t\tDONE";
     #endif
@@ -446,7 +454,7 @@ void kpMainWindow::updateThumbnail ()
     {
     #if DEBUG_KP_MAIN_WINDOW
         qCDebug(kpLogMainWindow) << "\tdestroying thumbnail d->thumbnail="
-            << d->thumbnail << endl;
+            << d->thumbnail;
     #endif
 
         if (d->thumbnailSaveConfigTimer && d->thumbnailSaveConfigTimer->isActive ())
@@ -457,8 +465,8 @@ void kpMainWindow::updateThumbnail ()
 
         // Must be done before hiding the thumbnail to avoid triggering
         // this signal - re-entering this code.
-        disconnect (d->thumbnail, SIGNAL (windowClosed()),
-                    this, SLOT (slotDestroyThumbnailInitatedByUser()));
+        disconnect (d->thumbnail, &kpThumbnail::windowClosed,
+                    this, &kpMainWindow::slotDestroyThumbnailInitatedByUser);
 
         // Avoid change/flicker of caption due to view delete
         // (destroyThumbnailView())
