@@ -41,11 +41,13 @@ kpToolAction::kpToolAction(const QString &text,
 {
   ac->setDefaultShortcuts(this, shortcut);
 
-  if ( receiver && slot )
-    connect(this, SIGNAL(triggered(bool)), receiver, slot);
+
+  if ( receiver && slot ) {
+      connect (this, SIGNAL(triggered(bool)), receiver, slot);
+  }
 
   updateToolTip();
-  connect(this, SIGNAL(changed()), this, SLOT(updateToolTip()));
+  connect (this, &kpToolAction::changed, this, &kpToolAction::updateToolTip);
 
   ac->addAction(name, this);
 }
@@ -58,8 +60,9 @@ void kpToolAction::updateToolTip()
   const QString newToolTip =
       kpTool::toolTipForTextAndShortcut(text(), shortcuts()).remove(QLatin1Char('&'));
 
-  if ( newToolTip == toolTip() )
+  if ( newToolTip == toolTip() ) {
     return;
+  }
 
   setToolTip(newToolTip);
 }
