@@ -32,14 +32,13 @@
 #include "imagelib/effects/kpEffectToneEnhance.h"
 #include "commands/imagelib/effects/kpEffectToneEnhanceCommand.h"
 #include "pixmapfx/kpPixmapFX.h"
+#include "kpNumInput.h"
 
 #include <QGridLayout>
 #include <QLabel>
 
 #include "kpLogCategories.h"
 #include <KLocalizedString>
-#include <knuminput.h> // kdelibs4support
-
 
 kpEffectToneEnhanceWidget::kpEffectToneEnhanceWidget (bool actOnSelection,
                                                       QWidget *parent)
@@ -48,46 +47,43 @@ kpEffectToneEnhanceWidget::kpEffectToneEnhanceWidget (bool actOnSelection,
       m_amountInput (nullptr)
 
 {
-    QGridLayout *lay = new QGridLayout (this);
-    lay->setMargin (0);
-
+    auto *lay = new QGridLayout (this);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     // See kpEffectToneEnhance::applyEffect().
-    {
-        QLabel *granularityLabel = new QLabel (i18n ("&Granularity:"), this);
 
-        QLabel *amountLabel = new QLabel (i18n ("&Amount:"), this);
+    auto *granularityLabel = new QLabel (i18n ("&Granularity:"), this);
 
-        m_granularityInput = new KDoubleNumInput (this);
-        m_granularityInput->setRange (0, 1, .1/*step*/, true/*slider*/);
+    auto *amountLabel = new QLabel (i18n ("&Amount:"), this);
 
-        m_amountInput = new KDoubleNumInput (this);
-        m_amountInput->setRange (0, 1, .1/*step*/, true/*slider*/);
+    m_granularityInput = new kpDoubleNumInput (this);
+    m_granularityInput->setRange (0, 1, 0.1/*step*/);
 
-        granularityLabel->setBuddy (m_granularityInput);
-        amountLabel->setBuddy (m_amountInput);
+    m_amountInput = new kpDoubleNumInput (this);
+    m_amountInput->setRange (0, 1, 0.1/*step*/);
+
+    granularityLabel->setBuddy (m_granularityInput);
+    amountLabel->setBuddy (m_amountInput);
 
 
-        lay->addWidget (granularityLabel, 0, 0);
-        lay->addWidget (m_granularityInput, 0, 1);
+    lay->addWidget (granularityLabel, 0, 0);
+    lay->addWidget (m_granularityInput, 0, 1);
 
-        lay->addWidget (amountLabel, 1, 0);
-        lay->addWidget (m_amountInput, 1, 1);
+    lay->addWidget (amountLabel, 1, 0);
+    lay->addWidget (m_amountInput, 1, 1);
 
-        lay->setColumnStretch (1, 1);
+    lay->setColumnStretch (1, 1);
 
 
-        connect (m_granularityInput, SIGNAL (valueChanged(double)),
-                 this, SIGNAL (settingsChangedDelayed()));
+    connect (m_granularityInput, &kpDoubleNumInput::valueChanged,
+             this, &kpEffectToneEnhanceWidget::settingsChangedDelayed);
+
+    connect (m_amountInput, &kpDoubleNumInput::valueChanged,
+             this, &kpEffectToneEnhanceWidget::settingsChangedDelayed);
 
-        connect (m_amountInput, SIGNAL (valueChanged(double)),
-                 this, SIGNAL (settingsChangedDelayed()));
-    }
 }
 
-kpEffectToneEnhanceWidget::~kpEffectToneEnhanceWidget ()
-{
-}
+kpEffectToneEnhanceWidget::~kpEffectToneEnhanceWidget () = default;
 
 
 // public virtual [base kpEffectWidgetBase]
@@ -117,10 +113,11 @@ bool kpEffectToneEnhanceWidget::isNoOp () const
     // If the "amount" is 0, nothing happens regardless of the granularity.
     // Note that if "granularity" is 0 but "amount" > 0, the effect _is_ active.
     // Therefore, "granularity" should have no involvement in this check.
-    if (amount () == 0)
+    if (amount () == 0) {
         return true;
-    else
-        return false;
+    }
+
+    return false;
 }
 
 // public virtual [base kpEffectWidgetBase]
