@@ -42,18 +42,18 @@
 #include <KSharedConfig>
 #include <KConfigGroup>
 
-#include <qapplication.h>
-#include <qboxlayout.h>
-#include <qbuffer.h>
-#include <qcombobox.h>
-#include <qevent.h>
-#include <qgridlayout.h>
-#include <qimage.h>
-#include <qlabel.h>
-#include <qlayout.h>
-#include <qpushbutton.h>
-#include <qspinbox.h>
-#include <qtimer.h>
+#include <QApplication>
+#include <QBoxLayout>
+#include <QBuffer>
+#include <QComboBox>
+#include <QEvent>
+#include <QGridLayout>
+#include <QImage>
+#include <QLabel>
+#include <QLayout>
+#include <QPushButton>
+#include <QSpinBox>
+#include <QTimer>
 
 
 kpDocumentSaveOptionsWidget::kpDocumentSaveOptionsWidget (
@@ -108,8 +108,8 @@ void kpDocumentSaveOptionsWidget::init ()
     m_qualityLabel->setBuddy (m_qualityInput);
 
 
-    QHBoxLayout *lay = new QHBoxLayout (this);
-    lay->setMargin(0);
+    auto *lay = new QHBoxLayout (this);
+    lay->setContentsMargins(0, 0, 0, 0);
 
     lay->addWidget (m_colorDepthLabel, 0/*stretch*/, Qt::AlignLeft);
     lay->addWidget (m_colorDepthCombo, 0/*stretch*/);
@@ -122,29 +122,33 @@ void kpDocumentSaveOptionsWidget::init ()
     lay->addWidget (m_previewButton, 0/*stretch*/, Qt::AlignRight);
 
 
-    connect (m_colorDepthCombo, SIGNAL (activated(int)),
-             this, SLOT (slotColorDepthSelected()));
-    connect (m_colorDepthCombo, SIGNAL (activated(int)),
-             this, SLOT (updatePreview()));
+    connect (m_colorDepthCombo,
+             static_cast<void (QComboBox::*)(int)>(&QComboBox::activated),
+             this, &kpDocumentSaveOptionsWidget::slotColorDepthSelected);
 
-    connect (m_qualityInput, SIGNAL (valueChanged(int)),
-             this, SLOT (updatePreviewDelayed()));
+    connect (m_colorDepthCombo,
+             static_cast<void (QComboBox::*)(int)>(&QComboBox::activated),
+             this, &kpDocumentSaveOptionsWidget::updatePreview);
 
-    connect (m_previewButton, SIGNAL (toggled(bool)),
-             this, SLOT (showPreview(bool)));
+    connect (m_qualityInput,
+             static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged),
+             this, &kpDocumentSaveOptionsWidget::updatePreviewDelayed);
+
+    connect (m_previewButton, &QPushButton::toggled,
+             this, &kpDocumentSaveOptionsWidget::showPreview);
 
 
     m_updatePreviewDelay = 200/*ms*/;
 
     m_updatePreviewTimer = new QTimer (this);
     m_updatePreviewTimer->setSingleShot (true);
-    connect (m_updatePreviewTimer, SIGNAL (timeout()),
-             this, SLOT (updatePreview()));
+    connect (m_updatePreviewTimer, &QTimer::timeout,
+             this, &kpDocumentSaveOptionsWidget::updatePreview);
 
     m_updatePreviewDialogLastRelativeGeometryTimer = new QTimer (this);
-    connect (m_updatePreviewDialogLastRelativeGeometryTimer, SIGNAL (timeout()),
-             this, SLOT (updatePreviewDialogLastRelativeGeometry()));
-
+    connect (m_updatePreviewDialogLastRelativeGeometryTimer,
+             &QTimer::timeout,
+             this, &kpDocumentSaveOptionsWidget::updatePreviewDialogLastRelativeGeometry);
 
     setMode (None);
 
@@ -260,12 +264,15 @@ void kpDocumentSaveOptionsWidget::setMimeType (const QString &string)
 
     m_baseDocumentSaveOptions.setMimeType (string);
 
-    if (mimeTypeHasConfigurableColorDepth ())
+    if (mimeTypeHasConfigurableColorDepth ()) {
         setMode (ColorDepth);
-    else if (mimeTypeHasConfigurableQuality ())
+    }
+    else if (mimeTypeHasConfigurableQuality ()) {
         setMode (Quality);
-    else
+    }
+    else {
         setMode (None);
+    }
 
     updatePreview ();
 }
@@ -309,44 +316,31 @@ bool kpDocumentSaveOptionsWidget::dither () const
         return (m_colorDepthCombo->currentIndex () == 1 ||
                 m_colorDepthCombo->currentIndex () == 3);
     }
-    else
-    {
-        return m_baseDocumentSaveOptions.dither ();
-    }
+
+    return m_baseDocumentSaveOptions.dither ();
 }
 
 // protected static
 int kpDocumentSaveOptionsWidget::colorDepthComboItemFromColorDepthAndDither (
     int depth, bool dither)
 {
-    if (depth == 1)
-    {
-        if (!dither)
-        {
+    switch (depth) {
+    case 1:
+        if (!dither) {
             return 0;
         }
-        else
-        {
-            return 1;
-        }
-    }
-    else if (depth == 8)
-    {
-        if (!dither)
-        {
+        return 1;
+
+    case 8:
+        if (!dither) {
             return 2;
         }
-        else
-        {
-            return 3;
-        }
-    }
-    else if (depth == 32)
-    {
+        return 3;
+
+    case 32:
         return 4;
-    }
-    else
-    {
+
+    default:
         return -1;
     }
 }
@@ -371,8 +365,9 @@ void kpDocumentSaveOptionsWidget::setColorDepthDither (int newDepth, bool newDit
     //       This happens if this mimeType has configurable colour depth
     //       and an incorrect maximum colour depth (less than a QImage of
     //       this mimeType, opened by kpDocument).
-    if (comboItem >= 0 && comboItem < m_colorDepthCombo->count ())
+    if (comboItem >= 0 && comboItem < m_colorDepthCombo->count ()) {
         m_colorDepthCombo->setCurrentIndex (comboItem);
+    }
 
 
     slotColorDepthSelected ();
@@ -411,10 +406,8 @@ int kpDocumentSaveOptionsWidget::quality () const
     {
         return m_qualityInput->value ();
     }
-    else
-    {
-        return m_baseDocumentSaveOptions.quality ();
-    }
+
+    return m_baseDocumentSaveOptions.quality ();
 }
 
 // public
@@ -505,10 +498,12 @@ void kpDocumentSaveOptionsWidget::setMode (Mode mode)
 // protected slot
 void kpDocumentSaveOptionsWidget::repaintLabels ()
 {
-    if (mode () != Quality)
+    if (mode () != Quality) {
         m_colorDepthLabel->repaint ();
-    if (mode () == Quality)
+    }
+    if (mode () == Quality) {
         m_qualityLabel->repaint ();
+    }
 }
 
 
@@ -521,11 +516,13 @@ void kpDocumentSaveOptionsWidget::showPreview (bool yes)
                << endl;
 #endif
 
-    if (yes == bool (m_previewDialog))
+    if (yes == bool (m_previewDialog)) {
         return;
+    }
 
-    if (!m_visualParent)
+    if (!m_visualParent) {
         return;
+    }
 
     if (yes)
     {
@@ -533,8 +530,8 @@ void kpDocumentSaveOptionsWidget::showPreview (bool yes)
         m_previewDialog->setObjectName( QLatin1String( "previewSaveDialog" ) );
         updatePreview ();
 
-        connect (m_previewDialog, SIGNAL (finished()),
-                 this, SLOT (hidePreview()));
+        connect (m_previewDialog, &kpDocumentSaveOptionsPreviewDialog::finished,
+                 this, &kpDocumentSaveOptionsWidget::hidePreview);
 
 
         KConfigGroup cfg (KSharedConfig::openConfig (), kpSettingsGroupPreviewSave);
@@ -549,12 +546,11 @@ void kpDocumentSaveOptionsWidget::showPreview (bool yes)
             cfg.sync ();
         }
 
-        if (m_updatePreviewDelay < 0)
+        if (m_updatePreviewDelay < 0) {
             m_updatePreviewDelay = 0;
+        }
     #if DEBUG_KP_DOCUMENT_SAVE_OPTIONS_WIDGET
-        qCDebug(kpLogWidgets) << "\tread cfg preview dialog update delay="
-                   << m_updatePreviewDelay
-                   << endl;
+        qCDebug(kpLogWidgets) << "\tread cfg preview dialog update delay=" << m_updatePreviewDelay;
     #endif
 
 
@@ -627,10 +623,11 @@ void kpDocumentSaveOptionsWidget::showPreview (bool yes)
 
         updatePreviewDialogLastRelativeGeometry ();
 
-        connect (m_previewDialog, SIGNAL (moved()),
-                 this, SLOT (updatePreviewDialogLastRelativeGeometry()));
-        connect (m_previewDialog, SIGNAL (resized()),
-                 this, SLOT (updatePreviewDialogLastRelativeGeometry()));
+        connect (m_previewDialog, &kpDocumentSaveOptionsPreviewDialog::moved,
+                 this, &kpDocumentSaveOptionsWidget::updatePreviewDialogLastRelativeGeometry);
+
+        connect (m_previewDialog, &kpDocumentSaveOptionsPreviewDialog::resized,
+                 this, &kpDocumentSaveOptionsWidget::updatePreviewDialogLastRelativeGeometry);
 
         m_updatePreviewDialogLastRelativeGeometryTimer->start (200/*ms*/);
     }
@@ -662,8 +659,9 @@ void kpDocumentSaveOptionsWidget::showPreview (bool yes)
 // protected slot
 void kpDocumentSaveOptionsWidget::hidePreview ()
 {
-    if (m_previewButton->isChecked ())
+    if (m_previewButton->isChecked ()) {
         m_previewButton->toggle ();
+    }
 }
 
 
@@ -677,8 +675,9 @@ void kpDocumentSaveOptionsWidget::updatePreviewDelayed ()
 // protected slot
 void kpDocumentSaveOptionsWidget::updatePreview ()
 {
-    if (!m_previewDialog || !m_documentPixmap)
+    if (!m_previewDialog || !m_documentPixmap) {
         return;
+    }
 
 
     m_updatePreviewTimer->stop ();
@@ -741,8 +740,7 @@ void kpDocumentSaveOptionsWidget::updatePreviewDialogLastRelativeGeometry ()
                        m_previewDialog->width (), m_previewDialog->height ()));
     #if DEBUG_KP_DOCUMENT_SAVE_OPTIONS_WIDGET
         qCDebug(kpLogWidgets) << "\tcaching pos = "
-                   << m_previewDialogLastRelativeGeometry
-                   << endl;
+                   << m_previewDialogLastRelativeGeometry;
     #endif
     }
     else
