@@ -31,11 +31,11 @@
 
 #include "widgets/toolbars/kpToolToolBar.h"
 
-#include <qboxlayout.h>
-#include <qgridlayout.h>
-#include <qbuttongroup.h>
-#include <qevent.h>
-#include <qtoolbutton.h>
+#include <QBoxLayout>
+#include <QGridLayout>
+#include <QButtonGroup>
+#include <QKeyEvent>
+#include <QToolButton>
 
 #include "kpLogCategories.h"
 
@@ -65,8 +65,9 @@ public:
 protected:
     void mouseDoubleClickEvent(QMouseEvent *e) override
     {
-        if (e->button () == Qt::LeftButton && m_tool)
+        if (e->button () == Qt::LeftButton && m_tool) {
             m_tool->globalDraw ();
+        }
     }
 
     kpTool *m_tool;
@@ -98,36 +99,39 @@ kpToolToolBar::kpToolToolBar(const QString &name, int colsOrRows, QMainWindow *p
     m_toolWidgets.append (m_toolWidgetSpraycanSize =
         new kpToolWidgetSpraycanSize (m_baseWidget, "Tool Widget Spraycan Size"));
 
-    foreach(kpToolWidgetBase *w, m_toolWidgets)
+    for (auto *w : m_toolWidgets)
     {
-      connect(w, SIGNAL(optionSelected(int,int)),
-              this, SIGNAL(toolWidgetOptionSelected()));
+      connect (w, &kpToolWidgetBase::optionSelected,
+               this, &kpToolToolBar::toolWidgetOptionSelected);
     }
 
     adjustToOrientation(orientation());
-    connect(this, SIGNAL(orientationChanged(Qt::Orientation)),
-            this, SLOT(adjustToOrientation(Qt::Orientation)));
+    connect (this, &kpToolToolBar::orientationChanged,
+             this, &kpToolToolBar::adjustToOrientation);
 
     m_buttonGroup = new QButtonGroup (this);
-    connect (m_buttonGroup, SIGNAL (buttonClicked(int)), SLOT (slotToolButtonClicked()));
+    connect (m_buttonGroup,
+             static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked),
+             this, &kpToolToolBar::slotToolButtonClicked);
 
     hideAllToolWidgets ();
 
     addWidget(m_baseWidget);
 
-    connect(this, SIGNAL(iconSizeChanged(QSize)),
-            this, SLOT(slotIconSizeChanged(QSize)));
+    connect (this, &kpToolToolBar::iconSizeChanged,
+             this, &kpToolToolBar::slotIconSizeChanged);
 
-    connect(this, SIGNAL(toolButtonStyleChanged(Qt::ToolButtonStyle)),
-            this, SLOT(slotToolButtonStyleChanged(Qt::ToolButtonStyle)));
+    connect (this, &kpToolToolBar::toolButtonStyleChanged,
+             this, &kpToolToolBar::slotToolButtonStyleChanged);
 }
 
 //---------------------------------------------------------------------
 
 kpToolToolBar::~kpToolToolBar()
 {
-  while ( !m_toolButtons.isEmpty() )
-   delete m_toolButtons.takeFirst();
+    while ( !m_toolButtons.isEmpty() ) {
+        delete m_toolButtons.takeFirst();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -135,13 +139,14 @@ kpToolToolBar::~kpToolToolBar()
 // public
 void kpToolToolBar::registerTool (kpTool *tool)
 {
-    foreach (const kpToolButton *b, m_toolButtons)
+    for (const auto *b : m_toolButtons)
     {
-      if ( b->tool() == tool )  // already given
-        return;
+        if ( b->tool() == tool ) {  // already given
+            return;
+        }
     }
 
-    kpToolButton *b = new kpToolButton(tool, m_baseWidget);
+    auto *b = new kpToolButton(tool, m_baseWidget);
 
     b->setToolButtonStyle(toolButtonStyle());
     b->setIconSize(iconSize());
@@ -157,8 +162,8 @@ void kpToolToolBar::registerTool (kpTool *tool)
 
     m_toolButtons.append(b);
 
-    connect (tool, SIGNAL (actionActivated()),
-             this, SLOT (slotToolActionActivated()));
+    connect (tool, &kpTool::actionActivated,
+             this, &kpToolToolBar::slotToolActionActivated);
 
     adjustSizeConstraint();
 }
@@ -173,8 +178,8 @@ void kpToolToolBar::unregisterTool(kpTool *tool)
       if ( m_toolButtons[i]->tool() == tool )
       {
         delete m_toolButtons.takeAt(i);
-        disconnect(tool, SIGNAL(actionActivated()),
-                   this, SLOT(slotToolActionActivated()));
+        disconnect (tool, &kpTool::actionActivated,
+                 this, &kpToolToolBar::slotToolActionActivated);
         return;
       }
     }
@@ -199,8 +204,9 @@ void kpToolToolBar::selectTool (const kpTool *tool, bool reselectIfSameTool)
                << endl;
 #endif
 
-    if (!reselectIfSameTool && tool == m_currentTool)
+    if (!reselectIfSameTool && tool == m_currentTool) {
         return;
+    }
 
     if (tool)
     {
@@ -250,8 +256,9 @@ void kpToolToolBar::selectPreviousTool ()
 // public
 void kpToolToolBar::hideAllToolWidgets ()
 {
-    foreach(kpToolWidgetBase *w, m_toolWidgets)
+    for (auto *w : m_toolWidgets) {
       w->hide ();
+    }
 }
 
 //---------------------------------------------------------------------
@@ -261,12 +268,13 @@ kpToolWidgetBase *kpToolToolBar::shownToolWidget (int which) const
 {
     int uptoVisibleWidget = 0;
 
-    foreach(kpToolWidgetBase *w, m_toolWidgets)
+    for(auto *w : m_toolWidgets)
     {
         if ( !w->isHidden() )
         {
-            if (which == uptoVisibleWidget)
+            if (which == uptoVisibleWidget) {
                 return w;
+            }
 
             uptoVisibleWidget++;
         }
@@ -287,7 +295,7 @@ void kpToolToolBar::slotToolButtonClicked ()
 #endif
 
     kpTool *tool = nullptr;
-    foreach (const kpToolButton *button, m_toolButtons)
+    for (const auto *button : m_toolButtons)
     {
       if ( button == b )
       {
@@ -304,14 +312,16 @@ void kpToolToolBar::slotToolButtonClicked ()
 
     if (tool == m_currentTool)
     {
-        if (m_currentTool)
+        if (m_currentTool) {
             m_currentTool->reselect ();
+        }
 
         return;
     }
 
-    if (m_currentTool)
+    if (m_currentTool) {
         m_currentTool->endInternal ();
+    }
 
     m_previousTool = m_currentTool;
     m_currentTool = tool;
@@ -337,7 +347,7 @@ void kpToolToolBar::slotToolButtonClicked ()
 // private slot
 void kpToolToolBar::slotToolActionActivated ()
 {
-    const kpTool *tool = dynamic_cast<const kpTool *>(sender());
+    const auto *tool = dynamic_cast<const kpTool *>(sender());
 
 #if DEBUG_KP_TOOL_TOOL_BAR
     qCDebug(kpLogWidgets) << "kpToolToolBar::slotToolActionActivated() tool="
@@ -377,15 +387,15 @@ void kpToolToolBar::adjustToOrientation(Qt::Orientation o)
     // (ownership is transferred to m_baseLayout)
     m_baseLayout->addItem (m_toolLayout);
 
-    int num = 0;
+    auto num = 0;
 
-    foreach (kpToolButton *b, m_toolButtons)
+    for (auto *b : m_toolButtons)
     {
       addButton(b, o, num);
       num++;
     }
 
-    foreach(kpToolWidgetBase *w, m_toolWidgets)
+    for (auto *w : m_toolWidgets)
     {
       m_baseLayout->addWidget(w,
           0/*stretch*/,
@@ -422,8 +432,9 @@ void kpToolToolBar::adjustSizeConstraint()
 // private
 void kpToolToolBar::addButton(QAbstractButton *button, Qt::Orientation o, int num)
 {
-    if (o == Qt::Vertical)
+    if (o == Qt::Vertical) {
         m_toolLayout->addWidget (button, num / m_vertCols, num % m_vertCols);
+    }
     else
     {
         // maps Left (o = vertical) to Bottom (o = horizontal)
@@ -436,8 +447,9 @@ void kpToolToolBar::addButton(QAbstractButton *button, Qt::Orientation o, int nu
 
 void kpToolToolBar::slotIconSizeChanged(const QSize &size)
 {
-    foreach (kpToolButton *b, m_toolButtons)
-      b->setIconSize(size);
+    for (auto *b : m_toolButtons) {
+        b->setIconSize(size);
+    }
 
     m_baseLayout->activate();
     adjustSizeConstraint();
@@ -447,8 +459,9 @@ void kpToolToolBar::slotIconSizeChanged(const QSize &size)
 
 void kpToolToolBar::slotToolButtonStyleChanged(Qt::ToolButtonStyle style)
 {
-    foreach (kpToolButton *b, m_toolButtons)
-      b->setToolButtonStyle(style);
+    for (auto *b : m_toolButtons) {
+        b->setToolButtonStyle(style);
+    }
 
     m_baseLayout->activate();
     adjustSizeConstraint();
